hedis
Safe HaskellNone
LanguageHaskell2010

Database.Redis.ManualCommands.CF

Synopsis

Documentation

data CFInfo Source #

Constructors

CFInfo 

Fields

Instances

Instances details
Show CFInfo Source # 
Instance details

Defined in Database.Redis.ManualCommands.CF

Eq CFInfo Source # 
Instance details

Defined in Database.Redis.ManualCommands.CF

Methods

(==) :: CFInfo -> CFInfo -> Bool #

(/=) :: CFInfo -> CFInfo -> Bool #

RedisResult CFInfo Source # 
Instance details

Defined in Database.Redis.ManualCommands.CF

data CFReserveOpts Source #

Constructors

CFReserveOpts 

Fields

data CFInsertOpts Source #

Constructors

CFInsertOpts 

Fields

cfadd Source #

Arguments

:: RedisCtx m f 
=> ByteString

Key of the Cuckoo filter.

-> ByteString

Item to add.

-> m (f Bool) 

Adds an item to a Cuckoo filter (https://redis.io/commands/cf.add).

A filter is created automatically if the key does not exist.

O(k + i), where k is the number of sub-filters and i is maxIterations.

Since RedisBloom 1.0.0

cfaddnx Source #

Arguments

:: RedisCtx m f 
=> ByteString

Key of the Cuckoo filter.

-> ByteString

Item to add.

-> m (f Bool) 

Adds an item to a Cuckoo filter only if it did not already exist (https://redis.io/commands/cf.addnx).

A filter is created automatically if the key does not exist.

O(k + i), where k is the number of sub-filters and i is maxIterations.

Since RedisBloom 1.0.0

cfcount Source #

Arguments

:: RedisCtx m f 
=> ByteString

Key of the Cuckoo filter.

-> ByteString

Item to count.

-> m (f Integer) 

Returns the number of times an item might appear in a Cuckoo filter (https://redis.io/commands/cf.count).

Returns 0 when the key does not exist or the item was not found.

O(k), where k is the number of sub-filters.

Since RedisBloom 1.0.0

cfdel Source #

Arguments

:: RedisCtx m f 
=> ByteString

Key of the Cuckoo filter.

-> ByteString

Item to delete.

-> m (f Bool) 

Deletes an item from a Cuckoo filter (https://redis.io/commands/cf.del).

Returns False when the key does not exist or the item was not found.

O(k), where k is the number of sub-filters.

Since RedisBloom 1.0.0

cfexists Source #

Arguments

:: RedisCtx m f 
=> ByteString

Key of the Cuckoo filter.

-> ByteString

Item to check.

-> m (f Bool) 

Checks whether an item may exist in a Cuckoo filter (https://redis.io/commands/cf.exists).

Returns False when the key does not exist or the item is definitely absent.

O(k), where k is the number of sub-filters.

Since RedisBloom 1.0.0

cfinfo Source #

Arguments

:: RedisCtx m f 
=> ByteString

Key of the Cuckoo filter.

-> m (f CFInfo) 

Returns information about a Cuckoo filter (https://redis.io/commands/cf.info).

O(1)

Since RedisBloom 1.0.0

cfinsert Source #

Arguments

:: RedisCtx m f 
=> ByteString

Key of the Cuckoo filter.

-> NonEmpty ByteString

Items to add.

-> m (f [CFInsertResult]) 

Adds one or more items to a Cuckoo filter, creating it when needed (https://redis.io/commands/cf.insert).

This is equivalent to inserting with default options and automatic creation enabled.

O(n * (k + i)), where n is the number of items, k is the number of sub-filters, and i is maxIterations.

Since RedisBloom 1.0.0

cfinsertOpts Source #

Arguments

:: RedisCtx m f 
=> ByteString

Key of the Cuckoo filter.

-> NonEmpty ByteString

Items to add.

-> CFInsertOpts

Optional creation parameters.

-> m (f [CFInsertResult]) 

Adds one or more items to a Cuckoo filter, creating it when needed (https://redis.io/commands/cf.insert).

O(n * (k + i)), where n is the number of items, k is the number of sub-filters, and i is maxIterations.

Since RedisBloom 1.0.0

cfinsertnx Source #

Arguments

:: RedisCtx m f 
=> ByteString

Key of the Cuckoo filter.

-> NonEmpty ByteString

Items to add.

-> m (f [CFInsertResult]) 

Adds one or more items to a Cuckoo filter only if they did not already exist (https://redis.io/commands/cf.insertnx).

This is equivalent to inserting with default options and automatic creation enabled.

O(n * (k + i)), where n is the number of items, k is the number of sub-filters, and i is maxIterations.

Since RedisBloom 1.0.0

cfinsertnxOpts Source #

Arguments

:: RedisCtx m f 
=> ByteString

Key of the Cuckoo filter.

-> NonEmpty ByteString

Items to add.

-> CFInsertOpts

Optional creation parameters.

-> m (f [CFInsertResult]) 

Adds one or more items to a Cuckoo filter only if they did not already exist (https://redis.io/commands/cf.insertnx).

O(n * (k + i)), where n is the number of items, k is the number of sub-filters, and i is maxIterations.

Since RedisBloom 1.0.0

cfmexists Source #

Arguments

:: RedisCtx m f 
=> ByteString

Key of the Cuckoo filter.

-> NonEmpty ByteString

Items to check.

-> m (f [Bool]) 

Checks whether one or more items may exist in a Cuckoo filter (https://redis.io/commands/cf.mexists).

A False result means the item is definitely absent, or the key does not exist.

O(k * n), where k is the number of sub-filters and n is the number of items.

Since RedisBloom 1.0.0

cfreserve Source #

Arguments

:: RedisCtx m f 
=> ByteString

Key of the Cuckoo filter to create.

-> Integer

Initial capacity.

-> m (f Status) 

Creates an empty Cuckoo filter (https://redis.io/commands/cf.reserve).

The filter will fail if the key already exists.

O(1)

Since RedisBloom 1.0.0

cfreserveOpts Source #

Arguments

:: RedisCtx m f 
=> ByteString

Key of the Cuckoo filter to create.

-> Integer

Initial capacity.

-> CFReserveOpts

Bucket and scaling options.

-> m (f Status) 

Creates an empty Cuckoo filter (https://redis.io/commands/cf.reserve).

O(1)

Since RedisBloom 1.0.0