hedis
Safe HaskellNone
LanguageHaskell2010

Database.Redis.ManualCommands.Cms

Synopsis

Documentation

data CMSInfo Source #

Constructors

CMSInfo 

Fields

Instances

Instances details
Show CMSInfo Source # 
Instance details

Defined in Database.Redis.ManualCommands.Cms

Eq CMSInfo Source # 
Instance details

Defined in Database.Redis.ManualCommands.Cms

Methods

(==) :: CMSInfo -> CMSInfo -> Bool #

(/=) :: CMSInfo -> CMSInfo -> Bool #

RedisResult CMSInfo Source # 
Instance details

Defined in Database.Redis.ManualCommands.Cms

data CMSMergeOpts Source #

Constructors

CMSMergeUnweighted (NonEmpty ByteString)

Merge the given source sketches using the default weight of 1.

CMSMergeWeighted (NonEmpty (ByteString, Integer))

Merge the given source sketches using an explicit weight for each source.

cmsincrby Source #

Arguments

:: RedisCtx m f 
=> ByteString

Key of the Count-Min Sketch.

-> NonEmpty (ByteString, Integer)

Item and increment pairs.

-> m (f [Integer]) 

Increases the count of one or more items by increment (https://redis.io/commands/cms.incrby).

O(n) where n is the number of items

Since RedisBloom 2.0.0

cmsinfo Source #

Arguments

:: RedisCtx m f 
=> ByteString

Key of the Count-Min Sketch.

-> m (f CMSInfo) 

Returns information about a sketch (https://redis.io/commands/cms.info).

O(1)

Since RedisBloom 2.0.0

cmsinitbydim Source #

Arguments

:: RedisCtx m f 
=> ByteString

Key of the Count-Min Sketch to create.

-> Integer

Number of counters in each row.

-> Integer

Number of counter rows.

-> m (f Status) 

Initializes a Count-Min Sketch to dimensions specified by user (https://redis.io/commands/cms.initbydim).

O(1)

Since RedisBloom 2.0.0

cmsinitbyprob Source #

Arguments

:: RedisCtx m f 
=> ByteString

Key of the Count-Min Sketch to create.

-> Double

Error factor.

-> Double

Probability of the error factor.

-> m (f Status) 

Initializes a Count-Min Sketch to accommodate requested tolerances (https://redis.io/commands/cms.initbyprob).

O(1)

Since RedisBloom 2.0.0

cmsmerge Source #

Arguments

:: RedisCtx m f 
=> ByteString

Destination sketch key.

-> NonEmpty ByteString

Source sketch keys.

-> m (f Status) 

Merges several sketches into one sketch (https://redis.io/commands/cms.merge).

Source sketches are merged with the default weight of 1.

O(n) where n is the number of sketches

Since RedisBloom 2.0.0

cmsmergeOpts Source #

Arguments

:: RedisCtx m f 
=> ByteString

Destination sketch key.

-> CMSMergeOpts

Source sketches with optional weights.

-> m (f Status) 

Merges several sketches into one sketch (https://redis.io/commands/cms.merge).

O(n) where n is the number of sketches

Since RedisBloom 2.0.0

cmsmergeWeighted Source #

Arguments

:: RedisCtx m f 
=> ByteString

Destination sketch key.

-> NonEmpty (ByteString, Integer)

Source sketch keys paired with weights.

-> m (f Status) 

Merges several sketches into one sketch (https://redis.io/commands/cms.merge).

O(n) where n is the number of sketches

Since RedisBloom 2.0.0

cmsquery Source #

Arguments

:: RedisCtx m f 
=> ByteString

Key of the Count-Min Sketch.

-> NonEmpty ByteString

Items to query.

-> m (f [Integer]) 

Returns the count for one or more items in a sketch (https://redis.io/commands/cms.query).

O(n) where n is the number of items

Since RedisBloom 2.0.0