hedis
Safe HaskellNone
LanguageHaskell2010

Database.Redis.ManualCommands.FT

Synopsis

Documentation

data FTOn Source #

Constructors

FTOnHash 
FTOnJson 

Instances

Instances details
Show FTOn Source # 
Instance details

Defined in Database.Redis.ManualCommands.FT

Methods

showsPrec :: Int -> FTOn -> ShowS #

show :: FTOn -> String #

showList :: [FTOn] -> ShowS #

Eq FTOn Source # 
Instance details

Defined in Database.Redis.ManualCommands.FT

Methods

(==) :: FTOn -> FTOn -> Bool #

(/=) :: FTOn -> FTOn -> Bool #

RedisArg FTOn Source # 
Instance details

Defined in Database.Redis.ManualCommands.FT

data FTSortable Source #

Constructors

FTSortable 
FTSortableUnf 

Instances

Instances details
Show FTSortable Source # 
Instance details

Defined in Database.Redis.ManualCommands.FT

Eq FTSortable Source # 
Instance details

Defined in Database.Redis.ManualCommands.FT

data FTAlterOpts Source #

Constructors

FTAlterOpts 

Instances

Instances details
Show FTAlterOpts Source # 
Instance details

Defined in Database.Redis.ManualCommands.FT

Eq FTAlterOpts Source # 
Instance details

Defined in Database.Redis.ManualCommands.FT

data FTSortBy Source #

Instances

Instances details
Show FTSortBy Source # 
Instance details

Defined in Database.Redis.ManualCommands.FT

Eq FTSortBy Source # 
Instance details

Defined in Database.Redis.ManualCommands.FT

data FTReduce Source #

Instances

Instances details
Show FTReduce Source # 
Instance details

Defined in Database.Redis.ManualCommands.FT

Eq FTReduce Source # 
Instance details

Defined in Database.Redis.ManualCommands.FT

data FTGroupBy Source #

Instances

Instances details
Show FTGroupBy Source # 
Instance details

Defined in Database.Redis.ManualCommands.FT

Eq FTGroupBy Source # 
Instance details

Defined in Database.Redis.ManualCommands.FT

data FTApply Source #

Instances

Instances details
Show FTApply Source # 
Instance details

Defined in Database.Redis.ManualCommands.FT

Eq FTApply Source # 
Instance details

Defined in Database.Redis.ManualCommands.FT

Methods

(==) :: FTApply -> FTApply -> Bool #

(/=) :: FTApply -> FTApply -> Bool #

ftList :: RedisCtx m f => m (f [ByteString]) Source #

Returns a list of all existing indexes (https://redis.io/commands/ft._list).

O(1)

Since RediSearch 2.0.0

ftAggregate Source #

Arguments

:: RedisCtx m f 
=> ByteString

Index name.

-> ByteString

Query string.

-> m (f Reply) 

Run a search query on an index and perform aggregate transformations on the results (https://redis.io/commands/ft.aggregate).

The reply shape varies with options such as WITHCURSOR, so this wrapper returns the raw Reply.

O(1)

Since RediSearch 1.1.0

ftAggregateOpts Source #

Arguments

:: RedisCtx m f 
=> ByteString

Index name.

-> ByteString

Query string.

-> FTAggregateOpts

Aggregate options and transformation steps.

-> m (f Reply) 

Run a search query on an index and perform aggregate transformations on the results (https://redis.io/commands/ft.aggregate).

The reply shape varies with options such as WITHCURSOR, so this wrapper returns the raw Reply.

O(1)

Since RediSearch 1.1.0

ftAliasAdd Source #

Arguments

:: RedisCtx m f 
=> ByteString

Alias name.

-> ByteString

Index name.

-> m (f Status) 

Adds an alias to the index (https://redis.io/commands/ft.aliasadd).

O(1)

Since RediSearch 1.0.0

ftAliasDel Source #

Arguments

:: RedisCtx m f 
=> ByteString

Alias name.

-> m (f Status) 

Deletes an alias from the index (https://redis.io/commands/ft.aliasdel).

O(1)

Since RediSearch 1.0.0

ftAliasUpdate Source #

Arguments

:: RedisCtx m f 
=> ByteString

Alias name.

-> ByteString

Index name.

-> m (f Status) 

Adds or updates an alias to the index (https://redis.io/commands/ft.aliasupdate).

O(1)

Since RediSearch 1.0.0

ftAlter Source #

Arguments

:: RedisCtx m f 
=> ByteString

Index name.

-> FTCreateField

Field definition to append to the schema.

-> m (f Status) 

Adds a new field to the index (https://redis.io/commands/ft.alter).

O(N) where N is the number of keys in the keyspace

Since RediSearch 1.0.0

ftAlterOpts Source #

Arguments

:: RedisCtx m f 
=> ByteString

Index name.

-> FTCreateField

Field definition to append to the schema.

-> FTAlterOpts

Alter options.

-> m (f Status) 

Adds a new field to the index (https://redis.io/commands/ft.alter).

O(N) where N is the number of keys in the keyspace

Since RediSearch 1.0.0

ftConfigSet Source #

Arguments

:: RedisCtx m f 
=> ByteString

Option name.

-> ByteString

Option value.

-> m (f Status) 

Sets runtime configuration options (https://redis.io/commands/ft.config-set).

O(1)

Since RediSearch 1.0.0

ftConfigGet Source #

Arguments

:: RedisCtx m f 
=> ByteString

Option name or pattern.

-> m (f Reply) 

Retrieves runtime configuration options (https://redis.io/commands/ft.config-get).

The server returns an option-dependent reply payload, so this wrapper returns the raw Reply.

O(1)

Since RediSearch 1.0.0

ftCreate Source #

Arguments

:: RedisCtx m f 
=> ByteString

Index name.

-> NonEmpty FTCreateField

Schema field definitions.

-> m (f Status) 

Creates an index with the given spec (https://redis.io/commands/ft.create).

O(K) at creation where K is the number of fields, O(N) if scanning the keyspace is triggered, where N is the number of keys in the keyspace

Since RediSearch 1.0.0

ftCreateOpts Source #

Arguments

:: RedisCtx m f 
=> ByteString

Index name.

-> NonEmpty FTCreateField

Schema field definitions.

-> FTCreateOpts

Index creation options.

-> m (f Status) 

Creates an index with the given spec (https://redis.io/commands/ft.create).

O(K) at creation where K is the number of fields, O(N) if scanning the keyspace is triggered, where N is the number of keys in the keyspace

Since RediSearch 1.0.0

ftCursorDel Source #

Arguments

:: RedisCtx m f 
=> ByteString

Index name.

-> Integer

Cursor identifier.

-> m (f Status) 

Deletes a cursor (https://redis.io/commands/ft.cursor-del).

O(1)

Since RediSearch 1.1.0

ftCursorRead Source #

Arguments

:: RedisCtx m f 
=> ByteString

Index name.

-> Integer

Cursor identifier.

-> m (f Reply) 

Reads from a cursor (https://redis.io/commands/ft.cursor-read).

The cursor batch payload is command-dependent, so this wrapper returns the raw Reply.

O(1)

Since RediSearch 1.1.0

ftCursorReadOpts Source #

Arguments

:: RedisCtx m f 
=> ByteString

Index name.

-> Integer

Cursor identifier.

-> FTCursorReadOpts

Cursor read options.

-> m (f Reply) 

Reads from a cursor (https://redis.io/commands/ft.cursor-read).

The cursor batch payload is command-dependent, so this wrapper returns the raw Reply.

O(1)

Since RediSearch 1.1.0

ftDictAdd Source #

Arguments

:: RedisCtx m f 
=> ByteString

Dictionary name.

-> NonEmpty ByteString

Terms to add.

-> m (f Integer) 

Adds terms to a dictionary (https://redis.io/commands/ft.dictadd).

O(1)

Since RediSearch 1.4.0

ftDictDel Source #

Arguments

:: RedisCtx m f 
=> ByteString

Dictionary name.

-> NonEmpty ByteString

Terms to delete.

-> m (f Integer) 

Deletes terms from a dictionary (https://redis.io/commands/ft.dictdel).

O(1)

Since RediSearch 1.4.0

ftDropIndex Source #

Arguments

:: RedisCtx m f 
=> ByteString

Index name.

-> m (f Status) 

Deletes the index (https://redis.io/commands/ft.dropindex).

O(1) or O(N) if documents are deleted, where N is the number of keys in the keyspace

Since RediSearch 2.0.0

ftDropIndexDeleteDocs Source #

Arguments

:: RedisCtx m f 
=> ByteString

Index name.

-> m (f Status) 

Deletes the index (https://redis.io/commands/ft.dropindex).

This variant also deletes indexed documents.

O(1) or O(N) if documents are deleted, where N is the number of keys in the keyspace

Since RediSearch 2.0.0

ftExplain Source #

Arguments

:: RedisCtx m f 
=> ByteString

Index name.

-> ByteString

Query string.

-> m (f ByteString) 

Returns the execution plan for a complex query (https://redis.io/commands/ft.explain).

O(1)

Since RediSearch 1.0.0

ftExplainOpts Source #

Arguments

:: RedisCtx m f 
=> ByteString

Index name.

-> ByteString

Query string.

-> FTExplainOpts

Explain options.

-> m (f ByteString) 

Returns the execution plan for a complex query (https://redis.io/commands/ft.explain).

O(1)

Since RediSearch 1.0.0

ftHybrid Source #

Arguments

:: RedisCtx m f 
=> ByteString

Index name.

-> FTHybridSearchClause

Textual search clause.

-> FTHybridVSimClause

Vector similarity clause.

-> m (f Reply) 

Performs hybrid search combining text search and vector similarity with configurable fusion methods (https://redis.io/commands/ft.hybrid).

The reply shape depends on requested projections and scoring options, so this wrapper returns the raw Reply.

O(N)

Since Redis Open Source 8.4.0

ftHybridOpts Source #

Arguments

:: RedisCtx m f 
=> ByteString

Index name.

-> FTHybridSearchClause

Textual search clause.

-> FTHybridVSimClause

Vector similarity clause.

-> FTHybridOpts

Hybrid query options.

-> m (f Reply) 

Performs hybrid search combining text search and vector similarity with configurable fusion methods (https://redis.io/commands/ft.hybrid).

The reply shape depends on requested projections and scoring options, so this wrapper returns the raw Reply.

O(N)

Since Redis Open Source 8.4.0

ftInfo Source #

Arguments

:: RedisCtx m f 
=> ByteString

Index name.

-> m (f Reply) 

Returns information and statistics on the index (https://redis.io/commands/ft.info).

The response is a heterogeneous attribute map, so this wrapper returns the raw Reply.

O(1)

Since RediSearch 1.0.0

ftProfile Source #

Arguments

:: RedisCtx m f 
=> ByteString

Index name.

-> FTProfileQueryType

Wrapped query type.

-> ByteString

Query payload for the wrapped command.

-> m (f Reply) 

Performs a SEARCH or AGGREGATE command and collects performance information (https://redis.io/commands/ft.profile).

The profiled reply depends on the wrapped query type, so this wrapper returns the raw Reply.

O(N)

Since RediSearch 2.2.0

ftProfileOpts Source #

Arguments

:: RedisCtx m f 
=> ByteString

Index name.

-> FTProfileQueryType

Wrapped query type.

-> ByteString

Query payload for the wrapped command.

-> FTProfileOpts

Profiling options.

-> m (f Reply) 

Performs a SEARCH or AGGREGATE command and collects performance information (https://redis.io/commands/ft.profile).

The profiled reply depends on the wrapped query type, so this wrapper returns the raw Reply.

O(N)

Since RediSearch 2.2.0

ftSearch Source #

Arguments

:: RedisCtx m f 
=> ByteString

Index name.

-> ByteString

Query string.

-> m (f Reply) 

Searches the index with a textual query, returning either documents or just ids (https://redis.io/commands/ft.search).

The reply shape depends on output flags such as NOCONTENT and WITHSCORES, so this wrapper returns the raw Reply.

O(N)

Since RediSearch 1.0.0

ftSearchOpts Source #

Arguments

:: RedisCtx m f 
=> ByteString

Index name.

-> ByteString

Query string.

-> FTSearchOpts

Search options.

-> m (f Reply) 

Searches the index with a textual query, returning either documents or just ids (https://redis.io/commands/ft.search).

The reply shape depends on output flags such as NOCONTENT and WITHSCORES, so this wrapper returns the raw Reply.

O(N)

Since RediSearch 1.0.0

ftSpellcheck Source #

Arguments

:: RedisCtx m f 
=> ByteString

Index name.

-> ByteString

Query string.

-> m (f Reply) 

Performs spelling correction on a query, returning suggestions for misspelled terms (https://redis.io/commands/ft.spellcheck).

The response contains nested suggestions, so this wrapper returns the raw Reply.

O(1)

Since RediSearch 1.4.0

ftSpellcheckOpts Source #

Arguments

:: RedisCtx m f 
=> ByteString

Index name.

-> ByteString

Query string.

-> FTSpellcheckOpts

Spellcheck options.

-> m (f Reply) 

Performs spelling correction on a query, returning suggestions for misspelled terms (https://redis.io/commands/ft.spellcheck).

The response contains nested suggestions, so this wrapper returns the raw Reply.

O(1)

Since RediSearch 1.4.0

ftSugAdd Source #

Arguments

:: RedisCtx m f 
=> ByteString

Suggestion dictionary key.

-> ByteString

Suggestion string.

-> Double

Suggestion score.

-> m (f Integer) 

Adds a suggestion string to an auto-complete suggestion dictionary (https://redis.io/commands/ft.sugadd).

O(1)

Since RediSearch 1.0.0

ftSugAddOpts Source #

Arguments

:: RedisCtx m f 
=> ByteString

Suggestion dictionary key.

-> ByteString

Suggestion string.

-> Double

Suggestion score.

-> FTSugAddOpts

Suggestion insertion options.

-> m (f Integer) 

Adds a suggestion string to an auto-complete suggestion dictionary (https://redis.io/commands/ft.sugadd).

O(1)

Since RediSearch 1.0.0

ftSugDel Source #

Arguments

:: RedisCtx m f 
=> ByteString

Suggestion dictionary key.

-> ByteString

Suggestion string.

-> m (f Integer) 

Deletes a string from a suggestion index (https://redis.io/commands/ft.sugdel).

O(1)

Since RediSearch 1.0.0

ftSugLen Source #

Arguments

:: RedisCtx m f 
=> ByteString

Suggestion dictionary key.

-> m (f Integer) 

Gets the size of an auto-complete suggestion dictionary (https://redis.io/commands/ft.suglen).

O(1)

Since RediSearch 1.0.0

ftTagVals Source #

Arguments

:: RedisCtx m f 
=> ByteString

Index name.

-> ByteString

Tag field name.

-> m (f [ByteString]) 

Returns the distinct tags indexed in a Tag field (https://redis.io/commands/ft.tagvals).

O(n) where n is the number of distinct tags in the field

Since RediSearch 1.0.0