hedis
Safe HaskellNone
LanguageHaskell2010

Database.Redis.ManualCommands.Ts

Synopsis

Documentation

data TsSample Source #

Instances

Instances details
Show TsSample Source # 
Instance details

Defined in Database.Redis.ManualCommands.Ts

Eq TsSample Source # 
Instance details

Defined in Database.Redis.ManualCommands.Ts

RedisResult TsSample Source # 
Instance details

Defined in Database.Redis.ManualCommands.Ts

data TsIgnore Source #

Instances

Instances details
Show TsIgnore Source # 
Instance details

Defined in Database.Redis.ManualCommands.Ts

Eq TsIgnore Source # 
Instance details

Defined in Database.Redis.ManualCommands.Ts

data TsGetOpts Source #

Constructors

TsGetOpts 

Fields

Instances

Instances details
Show TsGetOpts Source # 
Instance details

Defined in Database.Redis.ManualCommands.Ts

Eq TsGetOpts Source # 
Instance details

Defined in Database.Redis.ManualCommands.Ts

data TsInfoOpts Source #

Constructors

TsInfoDefault 
TsInfoDebug 

Instances

Instances details
Show TsInfoOpts Source # 
Instance details

Defined in Database.Redis.ManualCommands.Ts

Eq TsInfoOpts Source # 
Instance details

Defined in Database.Redis.ManualCommands.Ts

tsAdd Source #

Arguments

:: RedisCtx m f 
=> ByteString

Time series key.

-> ByteString

Timestamp, or * for the current server time.

-> Double

Sample value.

-> m (f Integer) 

Appends a sample to a time series (https://redis.io/commands/ts.add).

O(M) when M is the number of compaction rules, or O(1) with no compaction

Since RedisTimeSeries 1.0.0

tsAddOpts Source #

Arguments

:: RedisCtx m f 
=> ByteString

Time series key.

-> ByteString

Timestamp, or * for the current server time.

-> Double

Sample value.

-> TsAddOpts

Insertion options.

-> m (f Integer) 

Appends a sample to a time series (https://redis.io/commands/ts.add).

O(M) when M is the number of compaction rules, or O(1) with no compaction

Since RedisTimeSeries 1.0.0

tsAlter Source #

Arguments

:: RedisCtx m f 
=> ByteString

Time series key.

-> TsAlterOpts

Alteration options.

-> m (f Status) 

Update the retention, chunk size, duplicate policy, and labels of an existing time series (https://redis.io/commands/ts.alter).

O(N) where N is the number of labels requested to update

Since RedisTimeSeries 1.0.0

tsCreate Source #

Arguments

:: RedisCtx m f 
=> ByteString

Time series key.

-> m (f Status) 

Create a new time series (https://redis.io/commands/ts.create).

O(1)

Since RedisTimeSeries 1.0.0

tsCreateOpts Source #

Arguments

:: RedisCtx m f 
=> ByteString

Time series key.

-> TsCreateOpts

Creation options.

-> m (f Status) 

Create a new time series (https://redis.io/commands/ts.create).

O(1)

Since RedisTimeSeries 1.0.0

tsCreaterule Source #

Arguments

:: RedisCtx m f 
=> ByteString

Source time series key.

-> ByteString

Destination time series key.

-> TsAggregator

Aggregation function.

-> Integer

Bucket duration in milliseconds.

-> m (f Status) 

Create a compaction rule (https://redis.io/commands/ts.createrule).

O(1)

Since RedisTimeSeries 1.0.0

tsCreateruleAlign Source #

Arguments

:: RedisCtx m f 
=> ByteString

Source time series key.

-> ByteString

Destination time series key.

-> TsAggregator

Aggregation function.

-> Integer

Bucket duration in milliseconds.

-> Integer

Alignment timestamp in milliseconds.

-> m (f Status) 

Create a compaction rule with an aligned bucket timestamp (https://redis.io/commands/ts.createrule).

O(1)

Since RedisTimeSeries 1.8.0

tsDecrby Source #

Arguments

:: RedisCtx m f 
=> ByteString

Time series key.

-> Double

Decrement amount.

-> m (f Integer) 

Decrease the value of the sample with the maximum timestamp, or create a new sample with a decremented value (https://redis.io/commands/ts.decrby).

O(M) when M is the number of compaction rules, or O(1) with no compaction

Since RedisTimeSeries 1.0.0

tsDecrbyOpts Source #

Arguments

:: RedisCtx m f 
=> ByteString

Time series key.

-> Double

Decrement amount.

-> TsIncrByOpts

Update options.

-> m (f Integer) 

Decrease the value of the sample with the maximum timestamp, or create a new sample with a decremented value (https://redis.io/commands/ts.decrby).

O(M) when M is the number of compaction rules, or O(1) with no compaction

Since RedisTimeSeries 1.0.0

tsDel Source #

Arguments

:: RedisCtx m f 
=> ByteString

Time series key.

-> Integer

Lower timestamp bound.

-> Integer

Upper timestamp bound.

-> m (f Integer) 

Delete all samples between two timestamps for a given time series (https://redis.io/commands/ts.del).

O(N) where N is the number of data points that will be removed

Since RedisTimeSeries 1.6.0

tsDelrule Source #

Arguments

:: RedisCtx m f 
=> ByteString

Source time series key.

-> ByteString

Destination time series key.

-> m (f Status) 

Delete a compaction rule (https://redis.io/commands/ts.delrule).

O(1)

Since RedisTimeSeries 1.0.0

tsGet Source #

Arguments

:: RedisCtx m f 
=> ByteString

Time series key.

-> m (f (Maybe TsSample)) 

Get the sample with the highest timestamp from a given time series (https://redis.io/commands/ts.get).

O(1)

Since RedisTimeSeries 1.0.0

tsGetOpts Source #

Arguments

:: RedisCtx m f 
=> ByteString

Time series key.

-> TsGetOpts

Read options.

-> m (f (Maybe TsSample)) 

Get the sample with the highest timestamp from a given time series (https://redis.io/commands/ts.get).

O(1)

Since RedisTimeSeries 1.0.0

tsIncrby Source #

Arguments

:: RedisCtx m f 
=> ByteString

Time series key.

-> Double

Increment amount.

-> m (f Integer) 

Increase the value of the sample with the maximum timestamp, or create a new sample with an incremented value (https://redis.io/commands/ts.incrby).

O(M) when M is the number of compaction rules, or O(1) with no compaction

Since RedisTimeSeries 1.0.0

tsIncrbyOpts Source #

Arguments

:: RedisCtx m f 
=> ByteString

Time series key.

-> Double

Increment amount.

-> TsIncrByOpts

Update options.

-> m (f Integer) 

Increase the value of the sample with the maximum timestamp, or create a new sample with an incremented value (https://redis.io/commands/ts.incrby).

O(M) when M is the number of compaction rules, or O(1) with no compaction

Since RedisTimeSeries 1.0.0

tsInfo Source #

Arguments

:: RedisCtx m f 
=> ByteString

Time series key.

-> m (f Reply) 

Returns information and statistics for a time series (https://redis.io/commands/ts.info).

The reply is a heterogeneous attribute map, so this wrapper returns the raw Reply.

O(1)

Since RedisTimeSeries 1.0.0

tsInfoOpts Source #

Arguments

:: RedisCtx m f 
=> ByteString

Time series key.

-> TsInfoOpts

Information query options.

-> m (f Reply) 

Returns information and statistics for a time series (https://redis.io/commands/ts.info).

The reply is a heterogeneous attribute map, so this wrapper returns the raw Reply.

O(1)

Since RedisTimeSeries 1.0.0

tsMadd Source #

Arguments

:: RedisCtx m f 
=> NonEmpty (ByteString, ByteString, Double)

Time series key, timestamp, and sample value triplets.

-> m (f [Integer]) 

Append new samples to one or more time series (https://redis.io/commands/ts.madd).

O(N cdot M) when N is the number of series updated and M is the number of compaction rules, or O(N) with no compaction

Since RedisTimeSeries 1.0.0

tsMget Source #

Arguments

:: RedisCtx m f 
=> NonEmpty ByteString

Filter expressions.

-> m (f Reply) 

Get the sample with the highest timestamp from each time series matching a specific filter (https://redis.io/commands/ts.mget).

The reply is heterogeneous and depends on label options, so this wrapper returns the raw Reply.

O(n) where n is the number of time-series that match the filters

Since RedisTimeSeries 1.0.0

tsMgetOpts Source #

Arguments

:: RedisCtx m f 
=> NonEmpty ByteString

Filter expressions.

-> TsMGetOpts

Read options.

-> m (f Reply) 

Get the sample with the highest timestamp from each time series matching a specific filter (https://redis.io/commands/ts.mget).

The reply is heterogeneous and depends on label options, so this wrapper returns the raw Reply.

O(n) where n is the number of time-series that match the filters

Since RedisTimeSeries 1.0.0

tsMrange Source #

Arguments

:: RedisCtx m f 
=> ByteString

Lower timestamp bound, or -.

-> ByteString

Upper timestamp bound, or +.

-> NonEmpty ByteString

Filter expressions.

-> m (f Reply) 

Query a range across multiple time series by filters in forward direction (https://redis.io/commands/ts.mrange).

The reply is heterogeneous and may include labels or grouped output, so this wrapper returns the raw Reply.

O(n/m+k) where n is the number of data points, m is the chunk size, and k is the number of returned samples

Since RedisTimeSeries 1.0.0

tsMrangeOpts Source #

Arguments

:: RedisCtx m f 
=> ByteString

Lower timestamp bound, or -.

-> ByteString

Upper timestamp bound, or +.

-> NonEmpty ByteString

Filter expressions.

-> TsMRangeOpts

Query options.

-> m (f Reply) 

Query a range across multiple time series by filters in forward direction (https://redis.io/commands/ts.mrange).

The reply is heterogeneous and may include labels or grouped output, so this wrapper returns the raw Reply.

O(n/m+k) where n is the number of data points, m is the chunk size, and k is the number of returned samples

Since RedisTimeSeries 1.0.0

tsMrevrange Source #

Arguments

:: RedisCtx m f 
=> ByteString

Lower timestamp bound, or -.

-> ByteString

Upper timestamp bound, or +.

-> NonEmpty ByteString

Filter expressions.

-> m (f Reply) 

Query a range across multiple time series by filters in reverse direction (https://redis.io/commands/ts.mrevrange).

The reply is heterogeneous and may include labels or grouped output, so this wrapper returns the raw Reply.

O(n/m+k) where n is the number of data points, m is the chunk size, and k is the number of returned samples

Since RedisTimeSeries 1.4.0

tsMrevrangeOpts Source #

Arguments

:: RedisCtx m f 
=> ByteString

Lower timestamp bound, or -.

-> ByteString

Upper timestamp bound, or +.

-> NonEmpty ByteString

Filter expressions.

-> TsMRangeOpts

Query options.

-> m (f Reply) 

Query a range across multiple time series by filters in reverse direction (https://redis.io/commands/ts.mrevrange).

The reply is heterogeneous and may include labels or grouped output, so this wrapper returns the raw Reply.

O(n/m+k) where n is the number of data points, m is the chunk size, and k is the number of returned samples

Since RedisTimeSeries 1.4.0

tsQueryindex Source #

Arguments

:: RedisCtx m f 
=> NonEmpty ByteString

Filter expressions.

-> m (f [ByteString]) 

Get all time series keys matching a filter list (https://redis.io/commands/ts.queryindex).

O(n) where n is the number of time-series that match the filters

Since RedisTimeSeries 1.0.0

tsRange Source #

Arguments

:: RedisCtx m f 
=> ByteString

Time series key.

-> ByteString

Lower timestamp bound, or -.

-> ByteString

Upper timestamp bound, or +.

-> m (f [TsSample]) 

Query a range in forward direction (https://redis.io/commands/ts.range).

O(n/m+k) where n is the number of data points, m is the chunk size, and k is the number of returned samples

Since RedisTimeSeries 1.0.0

tsRangeOpts Source #

Arguments

:: RedisCtx m f 
=> ByteString

Time series key.

-> ByteString

Lower timestamp bound, or -.

-> ByteString

Upper timestamp bound, or +.

-> TsRangeOpts

Query options.

-> m (f [TsSample]) 

Query a range in forward direction (https://redis.io/commands/ts.range).

O(n/m+k) where n is the number of data points, m is the chunk size, and k is the number of returned samples

Since RedisTimeSeries 1.0.0

tsRevrange Source #

Arguments

:: RedisCtx m f 
=> ByteString

Time series key.

-> ByteString

Lower timestamp bound, or -.

-> ByteString

Upper timestamp bound, or +.

-> m (f [TsSample]) 

Query a range in reverse direction (https://redis.io/commands/ts.revrange).

O(n/m+k) where n is the number of data points, m is the chunk size, and k is the number of returned samples

Since RedisTimeSeries 1.4.0

tsRevrangeOpts Source #

Arguments

:: RedisCtx m f 
=> ByteString

Time series key.

-> ByteString

Lower timestamp bound, or -.

-> ByteString

Upper timestamp bound, or +.

-> TsRangeOpts

Query options.

-> m (f [TsSample]) 

Query a range in reverse direction (https://redis.io/commands/ts.revrange).

O(n/m+k) where n is the number of data points, m is the chunk size, and k is the number of returned samples

Since RedisTimeSeries 1.4.0