hedis
Safe HaskellNone
LanguageHaskell2010

Database.Redis.ManualCommands.Wait

Synopsis

Documentation

data WaitAofResult Source #

Constructors

WaitAofResult 

Fields

wait Source #

Arguments

:: RedisCtx m f 
=> Integer

Number of replicas to wait for.

-> Integer

Maximum time to wait in milliseconds. 0 means wait forever.

-> m (f Integer) 

O(1) Wait for preceding writes to be acknowledged by a given number of replicas (https://redis.io/commands/wait).

Blocks until the asynchronous replication of all preceding write commands sent by the connection is completed.

Since Redis 3.0.0

waitaof Source #

Arguments

:: RedisCtx m f 
=> Integer

Number of local Redis instances to wait for AOF fsync on (0 or 1).

-> Integer

Number of replicas to wait for AOF fsync on.

-> Integer

Maximum time to wait in milliseconds. 0 means wait forever.

-> m (f WaitAofResult) 

O(1) Wait for preceding writes to be fsynced to the append-only file locally and/or on replicas (https://redis.io/commands/waitaof).

Blocks until all of the preceding write commands sent by the connection are written to the append-only file of the master and/or replicas.

Since Redis 7.2.0