| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Database.Redis.ManualCommands.FT
Synopsis
- data FTOn
- data FTIndexAllMode
- data FTFieldIdentifier
- data FTSortable
- data FTCommonFieldOpts = FTCommonFieldOpts {}
- defaultFTCommonFieldOpts :: FTCommonFieldOpts
- data FTTextFieldOpts = FTTextFieldOpts {}
- defaultFTTextFieldOpts :: FTTextFieldOpts
- data FTTagFieldOpts = FTTagFieldOpts {}
- defaultFTTagFieldOpts :: FTTagFieldOpts
- data FTGeoShapeFieldOpts = FTGeoShapeFieldOpts {}
- defaultFTGeoShapeFieldOpts :: FTGeoShapeFieldOpts
- data FTVectorFieldOpts = FTVectorFieldOpts {}
- data FTCreateField
- = FTCreateTextField FTFieldIdentifier FTTextFieldOpts
- | FTCreateTagField FTFieldIdentifier FTTagFieldOpts
- | FTCreateNumericField FTFieldIdentifier FTCommonFieldOpts
- | FTCreateGeoField FTFieldIdentifier FTCommonFieldOpts
- | FTCreateGeoShapeField FTFieldIdentifier FTGeoShapeFieldOpts
- | FTCreateVectorField FTFieldIdentifier FTVectorFieldOpts
- data FTCreateOpts = FTCreateOpts {
- ftCreateOn :: Maybe FTOn
- ftCreateIndexAll :: Maybe FTIndexAllMode
- ftCreatePrefixes :: [ByteString]
- ftCreateFilter :: Maybe ByteString
- ftCreateLanguage :: Maybe ByteString
- ftCreateLanguageField :: Maybe ByteString
- ftCreateScore :: Maybe Double
- ftCreateScoreField :: Maybe ByteString
- ftCreatePayloadField :: Maybe ByteString
- ftCreateMaxTextFields :: Bool
- ftCreateTemporarySeconds :: Maybe Double
- ftCreateNoOffsets :: Bool
- ftCreateNoHl :: Bool
- ftCreateNoFields :: Bool
- ftCreateNoFreqs :: Bool
- ftCreateStopwords :: Maybe [ByteString]
- ftCreateSkipInitialScan :: Bool
- defaultFTCreateOpts :: FTCreateOpts
- data FTAlterOpts = FTAlterOpts {}
- defaultFTAlterOpts :: FTAlterOpts
- data FTExplainOpts = FTExplainOpts {}
- defaultFTExplainOpts :: FTExplainOpts
- data FTSearchContentMode
- data FTSearchScoreMode
- data FTSearchPayloadMode
- data FTSearchSortKeysMode
- data FTReturnField
- data FTSummarizeOpts = FTSummarizeOpts {}
- defaultFTSummarizeOpts :: FTSummarizeOpts
- data FTHighlightOpts = FTHighlightOpts {}
- defaultFTHighlightOpts :: FTHighlightOpts
- data FTNumericFilter = FTNumericFilter {}
- data FTGeoFilter = FTGeoFilter {}
- data FTSortBy = FTSortBy {}
- data FTSearchOpts = FTSearchOpts {
- ftSearchContentMode :: FTSearchContentMode
- ftSearchVerbatim :: Bool
- ftSearchNoStopWords :: Bool
- ftSearchScoreMode :: FTSearchScoreMode
- ftSearchPayloadMode :: FTSearchPayloadMode
- ftSearchSortKeysMode :: FTSearchSortKeysMode
- ftSearchNumericFilters :: [FTNumericFilter]
- ftSearchGeoFilters :: [FTGeoFilter]
- ftSearchInKeys :: [ByteString]
- ftSearchInFields :: [ByteString]
- ftSearchReturnFields :: [FTReturnField]
- ftSearchSummarize :: Maybe FTSummarizeOpts
- ftSearchHighlight :: Maybe FTHighlightOpts
- ftSearchSlop :: Maybe Integer
- ftSearchTimeout :: Maybe Integer
- ftSearchInOrder :: Bool
- ftSearchLanguage :: Maybe ByteString
- ftSearchExpander :: Maybe ByteString
- ftSearchScorer :: Maybe ByteString
- ftSearchPayload :: Maybe ByteString
- ftSearchSortBy :: Maybe FTSortBy
- ftSearchLimit :: Maybe (Integer, Integer)
- ftSearchParams :: [(ByteString, ByteString)]
- ftSearchDialect :: Maybe Integer
- defaultFTSearchOpts :: FTSearchOpts
- data FTAggregateLoad
- data FTSortProperty = FTSortProperty {}
- data FTReduce = FTReduce {}
- data FTGroupBy = FTGroupBy {}
- data FTApply = FTApply {}
- data FTCursorOpts = FTCursorOpts {}
- defaultFTCursorOpts :: FTCursorOpts
- data FTAggregateOpts = FTAggregateOpts {
- ftAggregateVerbatim :: Bool
- ftAggregateLoad :: Maybe FTAggregateLoad
- ftAggregateTimeout :: Maybe Integer
- ftAggregateGroupBy :: [FTGroupBy]
- ftAggregateSortBy :: Maybe (NonEmpty FTSortProperty, Maybe Integer)
- ftAggregateApply :: [FTApply]
- ftAggregateLimit :: Maybe (Integer, Integer)
- ftAggregateFilter :: Maybe ByteString
- ftAggregateCursor :: Maybe FTCursorOpts
- ftAggregateParams :: [(ByteString, ByteString)]
- ftAggregateDialect :: Maybe Integer
- defaultFTAggregateOpts :: FTAggregateOpts
- data FTHybridSearchClause = FTHybridSearchClause {}
- data FTHybridVectorQuery
- = FTHybridKnn { }
- | FTHybridRange { }
- data FTHybridVSimClause = FTHybridVSimClause {}
- data FTHybridCombine
- = FTHybridCombineRRF { }
- | FTHybridCombineLinear { }
- data FTHybridSort
- data FTHybridLoad
- data FTHybridOpts = FTHybridOpts {
- ftHybridCombine :: Maybe FTHybridCombine
- ftHybridLimit :: Maybe (Integer, Integer)
- ftHybridSorting :: Maybe FTHybridSort
- ftHybridParams :: [(ByteString, ByteString)]
- ftHybridTimeout :: Maybe Integer
- ftHybridFormat :: Maybe ByteString
- ftHybridLoad :: Maybe FTHybridLoad
- ftHybridGroupBy :: [FTGroupBy]
- ftHybridApply :: [FTApply]
- ftHybridFilter :: Maybe ByteString
- ftHybridDialect :: Maybe Integer
- defaultFTHybridOpts :: FTHybridOpts
- data FTProfileQueryType
- data FTProfileOpts = FTProfileOpts {}
- defaultFTProfileOpts :: FTProfileOpts
- data FTSpellcheckTermsMode
- data FTSpellcheckOpts = FTSpellcheckOpts {}
- defaultFTSpellcheckOpts :: FTSpellcheckOpts
- data FTSugAddOpts
- data FTCursorReadOpts = FTCursorReadOpts {}
- defaultFTCursorReadOpts :: FTCursorReadOpts
- countArgs :: [a] -> ByteString
- fieldIdentifierToArgs :: FTFieldIdentifier -> [ByteString]
- sortableToArgs :: FTSortable -> [ByteString]
- commonFieldOptsToArgs :: FTCommonFieldOpts -> [ByteString]
- createFieldToArgs :: FTCreateField -> [ByteString]
- ftCreateOptsToArgs :: FTCreateOpts -> [ByteString]
- ftAlterOptsToArgs :: FTAlterOpts -> [ByteString]
- ftExplainOptsToArgs :: FTExplainOpts -> [ByteString]
- returnFieldToArgs :: FTReturnField -> [ByteString]
- summarizeOptsToArgs :: FTSummarizeOpts -> [ByteString]
- highlightOptsToArgs :: FTHighlightOpts -> [ByteString]
- numericFilterToArgs :: FTNumericFilter -> [ByteString]
- geoFilterToArgs :: FTGeoFilter -> [ByteString]
- sortByToArgs :: FTSortBy -> [ByteString]
- ftSearchOptsToArgs :: FTSearchOpts -> [ByteString]
- aggregateLoadToArgs :: FTAggregateLoad -> [ByteString]
- sortPropertyToArgs :: FTSortProperty -> [ByteString]
- reduceToArgs :: FTReduce -> [ByteString]
- groupByToArgs :: FTGroupBy -> [ByteString]
- applyToArgs :: FTApply -> [ByteString]
- cursorOptsToArgs :: FTCursorOpts -> [ByteString]
- ftAggregateOptsToArgs :: FTAggregateOpts -> [ByteString]
- hybridVectorQueryToArgs :: FTHybridVectorQuery -> [ByteString]
- hybridSearchClauseToArgs :: FTHybridSearchClause -> [ByteString]
- hybridVSimClauseToArgs :: FTHybridVSimClause -> [ByteString]
- hybridCombineToArgs :: FTHybridCombine -> [ByteString]
- hybridSortToArgs :: FTHybridSort -> [ByteString]
- hybridLoadToArgs :: FTHybridLoad -> [ByteString]
- ftHybridOptsToArgs :: FTHybridOpts -> [ByteString]
- ftProfileOptsToArgs :: FTProfileOpts -> [ByteString]
- spellcheckTermsModeToArgs :: FTSpellcheckTermsMode -> [ByteString]
- ftSpellcheckOptsToArgs :: FTSpellcheckOpts -> [ByteString]
- ftSugAddOptsToArgs :: FTSugAddOpts -> [ByteString]
- ftCursorReadOptsToArgs :: FTCursorReadOpts -> [ByteString]
- ftList :: RedisCtx m f => m (f [ByteString])
- ftAggregate :: RedisCtx m f => ByteString -> ByteString -> m (f Reply)
- ftAggregateOpts :: RedisCtx m f => ByteString -> ByteString -> FTAggregateOpts -> m (f Reply)
- ftAliasAdd :: RedisCtx m f => ByteString -> ByteString -> m (f Status)
- ftAliasDel :: RedisCtx m f => ByteString -> m (f Status)
- ftAliasUpdate :: RedisCtx m f => ByteString -> ByteString -> m (f Status)
- ftAlter :: RedisCtx m f => ByteString -> FTCreateField -> m (f Status)
- ftAlterOpts :: RedisCtx m f => ByteString -> FTCreateField -> FTAlterOpts -> m (f Status)
- ftConfigSet :: RedisCtx m f => ByteString -> ByteString -> m (f Status)
- ftConfigGet :: RedisCtx m f => ByteString -> m (f Reply)
- ftCreate :: RedisCtx m f => ByteString -> NonEmpty FTCreateField -> m (f Status)
- ftCreateOpts :: RedisCtx m f => ByteString -> NonEmpty FTCreateField -> FTCreateOpts -> m (f Status)
- ftCursorDel :: RedisCtx m f => ByteString -> Integer -> m (f Status)
- ftCursorRead :: RedisCtx m f => ByteString -> Integer -> m (f Reply)
- ftCursorReadOpts :: RedisCtx m f => ByteString -> Integer -> FTCursorReadOpts -> m (f Reply)
- ftDictAdd :: RedisCtx m f => ByteString -> NonEmpty ByteString -> m (f Integer)
- ftDictDel :: RedisCtx m f => ByteString -> NonEmpty ByteString -> m (f Integer)
- ftDropIndex :: RedisCtx m f => ByteString -> m (f Status)
- ftDropIndexDeleteDocs :: RedisCtx m f => ByteString -> m (f Status)
- ftExplain :: RedisCtx m f => ByteString -> ByteString -> m (f ByteString)
- ftExplainOpts :: RedisCtx m f => ByteString -> ByteString -> FTExplainOpts -> m (f ByteString)
- ftHybrid :: RedisCtx m f => ByteString -> FTHybridSearchClause -> FTHybridVSimClause -> m (f Reply)
- ftHybridOpts :: RedisCtx m f => ByteString -> FTHybridSearchClause -> FTHybridVSimClause -> FTHybridOpts -> m (f Reply)
- ftInfo :: RedisCtx m f => ByteString -> m (f Reply)
- ftProfile :: RedisCtx m f => ByteString -> FTProfileQueryType -> ByteString -> m (f Reply)
- ftProfileOpts :: RedisCtx m f => ByteString -> FTProfileQueryType -> ByteString -> FTProfileOpts -> m (f Reply)
- ftSearch :: RedisCtx m f => ByteString -> ByteString -> m (f Reply)
- ftSearchOpts :: RedisCtx m f => ByteString -> ByteString -> FTSearchOpts -> m (f Reply)
- ftSpellcheck :: RedisCtx m f => ByteString -> ByteString -> m (f Reply)
- ftSpellcheckOpts :: RedisCtx m f => ByteString -> ByteString -> FTSpellcheckOpts -> m (f Reply)
- ftSugAdd :: RedisCtx m f => ByteString -> ByteString -> Double -> m (f Integer)
- ftSugAddOpts :: RedisCtx m f => ByteString -> ByteString -> Double -> FTSugAddOpts -> m (f Integer)
- ftSugDel :: RedisCtx m f => ByteString -> ByteString -> m (f Integer)
- ftSugLen :: RedisCtx m f => ByteString -> m (f Integer)
- ftTagVals :: RedisCtx m f => ByteString -> ByteString -> m (f [ByteString])
Documentation
data FTIndexAllMode Source #
Constructors
| FTIndexAllEnable | |
| FTIndexAllDisable |
Instances
| Show FTIndexAllMode Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTIndexAllMode -> ShowS # show :: FTIndexAllMode -> String # showList :: [FTIndexAllMode] -> ShowS # | |
| Eq FTIndexAllMode Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTIndexAllMode -> FTIndexAllMode -> Bool # (/=) :: FTIndexAllMode -> FTIndexAllMode -> Bool # | |
| RedisArg FTIndexAllMode Source # | |
Defined in Database.Redis.ManualCommands.FT Methods encode :: FTIndexAllMode -> ByteString Source # | |
data FTFieldIdentifier Source #
Constructors
| FTFieldName ByteString | |
| FTFieldNameAs ByteString ByteString |
Instances
| Show FTFieldIdentifier Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTFieldIdentifier -> ShowS # show :: FTFieldIdentifier -> String # showList :: [FTFieldIdentifier] -> ShowS # | |
| Eq FTFieldIdentifier Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTFieldIdentifier -> FTFieldIdentifier -> Bool # (/=) :: FTFieldIdentifier -> FTFieldIdentifier -> Bool # | |
data FTSortable Source #
Constructors
| FTSortable | |
| FTSortableUnf |
Instances
| Show FTSortable Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTSortable -> ShowS # show :: FTSortable -> String # showList :: [FTSortable] -> ShowS # | |
| Eq FTSortable Source # | |
Defined in Database.Redis.ManualCommands.FT | |
data FTCommonFieldOpts Source #
Constructors
| FTCommonFieldOpts | |
Instances
| Show FTCommonFieldOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTCommonFieldOpts -> ShowS # show :: FTCommonFieldOpts -> String # showList :: [FTCommonFieldOpts] -> ShowS # | |
| Eq FTCommonFieldOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTCommonFieldOpts -> FTCommonFieldOpts -> Bool # (/=) :: FTCommonFieldOpts -> FTCommonFieldOpts -> Bool # | |
data FTTextFieldOpts Source #
Constructors
| FTTextFieldOpts | |
Instances
| Show FTTextFieldOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTTextFieldOpts -> ShowS # show :: FTTextFieldOpts -> String # showList :: [FTTextFieldOpts] -> ShowS # | |
| Eq FTTextFieldOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTTextFieldOpts -> FTTextFieldOpts -> Bool # (/=) :: FTTextFieldOpts -> FTTextFieldOpts -> Bool # | |
data FTTagFieldOpts Source #
Constructors
| FTTagFieldOpts | |
Instances
| Show FTTagFieldOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTTagFieldOpts -> ShowS # show :: FTTagFieldOpts -> String # showList :: [FTTagFieldOpts] -> ShowS # | |
| Eq FTTagFieldOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTTagFieldOpts -> FTTagFieldOpts -> Bool # (/=) :: FTTagFieldOpts -> FTTagFieldOpts -> Bool # | |
data FTGeoShapeFieldOpts Source #
Constructors
| FTGeoShapeFieldOpts | |
Instances
| Show FTGeoShapeFieldOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTGeoShapeFieldOpts -> ShowS # show :: FTGeoShapeFieldOpts -> String # showList :: [FTGeoShapeFieldOpts] -> ShowS # | |
| Eq FTGeoShapeFieldOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTGeoShapeFieldOpts -> FTGeoShapeFieldOpts -> Bool # (/=) :: FTGeoShapeFieldOpts -> FTGeoShapeFieldOpts -> Bool # | |
data FTVectorFieldOpts Source #
Constructors
| FTVectorFieldOpts | |
Instances
| Show FTVectorFieldOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTVectorFieldOpts -> ShowS # show :: FTVectorFieldOpts -> String # showList :: [FTVectorFieldOpts] -> ShowS # | |
| Eq FTVectorFieldOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTVectorFieldOpts -> FTVectorFieldOpts -> Bool # (/=) :: FTVectorFieldOpts -> FTVectorFieldOpts -> Bool # | |
data FTCreateField Source #
Constructors
Instances
| Show FTCreateField Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTCreateField -> ShowS # show :: FTCreateField -> String # showList :: [FTCreateField] -> ShowS # | |
| Eq FTCreateField Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTCreateField -> FTCreateField -> Bool # (/=) :: FTCreateField -> FTCreateField -> Bool # | |
data FTCreateOpts Source #
Constructors
Instances
| Show FTCreateOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTCreateOpts -> ShowS # show :: FTCreateOpts -> String # showList :: [FTCreateOpts] -> ShowS # | |
| Eq FTCreateOpts Source # | |
Defined in Database.Redis.ManualCommands.FT | |
data FTAlterOpts Source #
Constructors
| FTAlterOpts | |
Fields | |
Instances
| Show FTAlterOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTAlterOpts -> ShowS # show :: FTAlterOpts -> String # showList :: [FTAlterOpts] -> ShowS # | |
| Eq FTAlterOpts Source # | |
Defined in Database.Redis.ManualCommands.FT | |
data FTExplainOpts Source #
Constructors
| FTExplainOpts | |
Fields | |
Instances
| Show FTExplainOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTExplainOpts -> ShowS # show :: FTExplainOpts -> String # showList :: [FTExplainOpts] -> ShowS # | |
| Eq FTExplainOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTExplainOpts -> FTExplainOpts -> Bool # (/=) :: FTExplainOpts -> FTExplainOpts -> Bool # | |
data FTSearchContentMode Source #
Constructors
| FTSearchReturnDocuments | |
| FTSearchReturnIdsOnly |
Instances
| Show FTSearchContentMode Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTSearchContentMode -> ShowS # show :: FTSearchContentMode -> String # showList :: [FTSearchContentMode] -> ShowS # | |
| Eq FTSearchContentMode Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTSearchContentMode -> FTSearchContentMode -> Bool # (/=) :: FTSearchContentMode -> FTSearchContentMode -> Bool # | |
data FTSearchScoreMode Source #
Instances
| Show FTSearchScoreMode Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTSearchScoreMode -> ShowS # show :: FTSearchScoreMode -> String # showList :: [FTSearchScoreMode] -> ShowS # | |
| Eq FTSearchScoreMode Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTSearchScoreMode -> FTSearchScoreMode -> Bool # (/=) :: FTSearchScoreMode -> FTSearchScoreMode -> Bool # | |
data FTSearchPayloadMode Source #
Constructors
| FTSearchNoPayloads | |
| FTSearchWithPayloads |
Instances
| Show FTSearchPayloadMode Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTSearchPayloadMode -> ShowS # show :: FTSearchPayloadMode -> String # showList :: [FTSearchPayloadMode] -> ShowS # | |
| Eq FTSearchPayloadMode Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTSearchPayloadMode -> FTSearchPayloadMode -> Bool # (/=) :: FTSearchPayloadMode -> FTSearchPayloadMode -> Bool # | |
data FTSearchSortKeysMode Source #
Constructors
| FTSearchNoSortKeys | |
| FTSearchWithSortKeys |
Instances
| Show FTSearchSortKeysMode Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTSearchSortKeysMode -> ShowS # show :: FTSearchSortKeysMode -> String # showList :: [FTSearchSortKeysMode] -> ShowS # | |
| Eq FTSearchSortKeysMode Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTSearchSortKeysMode -> FTSearchSortKeysMode -> Bool # (/=) :: FTSearchSortKeysMode -> FTSearchSortKeysMode -> Bool # | |
data FTReturnField Source #
Constructors
| FTReturnField ByteString | |
| FTReturnFieldAs ByteString ByteString |
Instances
| Show FTReturnField Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTReturnField -> ShowS # show :: FTReturnField -> String # showList :: [FTReturnField] -> ShowS # | |
| Eq FTReturnField Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTReturnField -> FTReturnField -> Bool # (/=) :: FTReturnField -> FTReturnField -> Bool # | |
data FTSummarizeOpts Source #
Constructors
| FTSummarizeOpts | |
Fields | |
Instances
| Show FTSummarizeOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTSummarizeOpts -> ShowS # show :: FTSummarizeOpts -> String # showList :: [FTSummarizeOpts] -> ShowS # | |
| Eq FTSummarizeOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTSummarizeOpts -> FTSummarizeOpts -> Bool # (/=) :: FTSummarizeOpts -> FTSummarizeOpts -> Bool # | |
data FTHighlightOpts Source #
Constructors
| FTHighlightOpts | |
Fields | |
Instances
| Show FTHighlightOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTHighlightOpts -> ShowS # show :: FTHighlightOpts -> String # showList :: [FTHighlightOpts] -> ShowS # | |
| Eq FTHighlightOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTHighlightOpts -> FTHighlightOpts -> Bool # (/=) :: FTHighlightOpts -> FTHighlightOpts -> Bool # | |
data FTNumericFilter Source #
Constructors
| FTNumericFilter | |
Fields | |
Instances
| Show FTNumericFilter Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTNumericFilter -> ShowS # show :: FTNumericFilter -> String # showList :: [FTNumericFilter] -> ShowS # | |
| Eq FTNumericFilter Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTNumericFilter -> FTNumericFilter -> Bool # (/=) :: FTNumericFilter -> FTNumericFilter -> Bool # | |
data FTGeoFilter Source #
Constructors
| FTGeoFilter | |
Instances
| Show FTGeoFilter Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTGeoFilter -> ShowS # show :: FTGeoFilter -> String # showList :: [FTGeoFilter] -> ShowS # | |
| Eq FTGeoFilter Source # | |
Defined in Database.Redis.ManualCommands.FT | |
data FTSearchOpts Source #
Constructors
Instances
| Show FTSearchOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTSearchOpts -> ShowS # show :: FTSearchOpts -> String # showList :: [FTSearchOpts] -> ShowS # | |
| Eq FTSearchOpts Source # | |
Defined in Database.Redis.ManualCommands.FT | |
data FTAggregateLoad Source #
Constructors
| FTAggregateLoadAll | |
| FTAggregateLoadFields (NonEmpty ByteString) |
Instances
| Show FTAggregateLoad Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTAggregateLoad -> ShowS # show :: FTAggregateLoad -> String # showList :: [FTAggregateLoad] -> ShowS # | |
| Eq FTAggregateLoad Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTAggregateLoad -> FTAggregateLoad -> Bool # (/=) :: FTAggregateLoad -> FTAggregateLoad -> Bool # | |
data FTSortProperty Source #
Constructors
| FTSortProperty | |
Fields | |
Instances
| Show FTSortProperty Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTSortProperty -> ShowS # show :: FTSortProperty -> String # showList :: [FTSortProperty] -> ShowS # | |
| Eq FTSortProperty Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTSortProperty -> FTSortProperty -> Bool # (/=) :: FTSortProperty -> FTSortProperty -> Bool # | |
data FTCursorOpts Source #
Constructors
| FTCursorOpts | |
Fields | |
Instances
| Show FTCursorOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTCursorOpts -> ShowS # show :: FTCursorOpts -> String # showList :: [FTCursorOpts] -> ShowS # | |
| Eq FTCursorOpts Source # | |
Defined in Database.Redis.ManualCommands.FT | |
data FTAggregateOpts Source #
Constructors
Instances
| Show FTAggregateOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTAggregateOpts -> ShowS # show :: FTAggregateOpts -> String # showList :: [FTAggregateOpts] -> ShowS # | |
| Eq FTAggregateOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTAggregateOpts -> FTAggregateOpts -> Bool # (/=) :: FTAggregateOpts -> FTAggregateOpts -> Bool # | |
data FTHybridSearchClause Source #
Constructors
| FTHybridSearchClause | |
Instances
| Show FTHybridSearchClause Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTHybridSearchClause -> ShowS # show :: FTHybridSearchClause -> String # showList :: [FTHybridSearchClause] -> ShowS # | |
| Eq FTHybridSearchClause Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTHybridSearchClause -> FTHybridSearchClause -> Bool # (/=) :: FTHybridSearchClause -> FTHybridSearchClause -> Bool # | |
data FTHybridVectorQuery Source #
Constructors
| FTHybridKnn | |
| FTHybridRange | |
Instances
| Show FTHybridVectorQuery Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTHybridVectorQuery -> ShowS # show :: FTHybridVectorQuery -> String # showList :: [FTHybridVectorQuery] -> ShowS # | |
| Eq FTHybridVectorQuery Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTHybridVectorQuery -> FTHybridVectorQuery -> Bool # (/=) :: FTHybridVectorQuery -> FTHybridVectorQuery -> Bool # | |
data FTHybridVSimClause Source #
Constructors
| FTHybridVSimClause | |
Instances
| Show FTHybridVSimClause Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTHybridVSimClause -> ShowS # show :: FTHybridVSimClause -> String # showList :: [FTHybridVSimClause] -> ShowS # | |
| Eq FTHybridVSimClause Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTHybridVSimClause -> FTHybridVSimClause -> Bool # (/=) :: FTHybridVSimClause -> FTHybridVSimClause -> Bool # | |
data FTHybridCombine Source #
Constructors
| FTHybridCombineRRF | |
| FTHybridCombineLinear | |
Instances
| Show FTHybridCombine Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTHybridCombine -> ShowS # show :: FTHybridCombine -> String # showList :: [FTHybridCombine] -> ShowS # | |
| Eq FTHybridCombine Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTHybridCombine -> FTHybridCombine -> Bool # (/=) :: FTHybridCombine -> FTHybridCombine -> Bool # | |
data FTHybridSort Source #
Constructors
| FTHybridSortBy ByteString (Maybe SortOrder) | |
| FTHybridNoSort |
Instances
| Show FTHybridSort Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTHybridSort -> ShowS # show :: FTHybridSort -> String # showList :: [FTHybridSort] -> ShowS # | |
| Eq FTHybridSort Source # | |
Defined in Database.Redis.ManualCommands.FT | |
data FTHybridLoad Source #
Constructors
| FTHybridLoadFields (NonEmpty ByteString) | |
| FTHybridLoadAll |
Instances
| Show FTHybridLoad Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTHybridLoad -> ShowS # show :: FTHybridLoad -> String # showList :: [FTHybridLoad] -> ShowS # | |
| Eq FTHybridLoad Source # | |
Defined in Database.Redis.ManualCommands.FT | |
data FTHybridOpts Source #
Constructors
| FTHybridOpts | |
Fields
| |
Instances
| Show FTHybridOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTHybridOpts -> ShowS # show :: FTHybridOpts -> String # showList :: [FTHybridOpts] -> ShowS # | |
| Eq FTHybridOpts Source # | |
Defined in Database.Redis.ManualCommands.FT | |
data FTProfileQueryType Source #
Constructors
| FTProfileSearch | |
| FTProfileHybrid | |
| FTProfileAggregate |
Instances
| Show FTProfileQueryType Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTProfileQueryType -> ShowS # show :: FTProfileQueryType -> String # showList :: [FTProfileQueryType] -> ShowS # | |
| Eq FTProfileQueryType Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTProfileQueryType -> FTProfileQueryType -> Bool # (/=) :: FTProfileQueryType -> FTProfileQueryType -> Bool # | |
| RedisArg FTProfileQueryType Source # | |
Defined in Database.Redis.ManualCommands.FT Methods | |
data FTProfileOpts Source #
Constructors
| FTProfileOpts | |
Fields | |
Instances
| Show FTProfileOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTProfileOpts -> ShowS # show :: FTProfileOpts -> String # showList :: [FTProfileOpts] -> ShowS # | |
| Eq FTProfileOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTProfileOpts -> FTProfileOpts -> Bool # (/=) :: FTProfileOpts -> FTProfileOpts -> Bool # | |
data FTSpellcheckTermsMode Source #
Constructors
| FTSpellcheckInclude ByteString [ByteString] | |
| FTSpellcheckExclude ByteString [ByteString] |
Instances
| Show FTSpellcheckTermsMode Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTSpellcheckTermsMode -> ShowS # show :: FTSpellcheckTermsMode -> String # showList :: [FTSpellcheckTermsMode] -> ShowS # | |
| Eq FTSpellcheckTermsMode Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTSpellcheckTermsMode -> FTSpellcheckTermsMode -> Bool # (/=) :: FTSpellcheckTermsMode -> FTSpellcheckTermsMode -> Bool # | |
data FTSpellcheckOpts Source #
Constructors
| FTSpellcheckOpts | |
Instances
| Show FTSpellcheckOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTSpellcheckOpts -> ShowS # show :: FTSpellcheckOpts -> String # showList :: [FTSpellcheckOpts] -> ShowS # | |
| Eq FTSpellcheckOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTSpellcheckOpts -> FTSpellcheckOpts -> Bool # (/=) :: FTSpellcheckOpts -> FTSpellcheckOpts -> Bool # | |
data FTSugAddOpts Source #
Constructors
| FTSugAddDefault | |
| FTSugAddWithPayload ByteString | |
| FTSugAddIncrement | |
| FTSugAddIncrementWithPayload ByteString |
Instances
| Show FTSugAddOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTSugAddOpts -> ShowS # show :: FTSugAddOpts -> String # showList :: [FTSugAddOpts] -> ShowS # | |
| Eq FTSugAddOpts Source # | |
Defined in Database.Redis.ManualCommands.FT | |
data FTCursorReadOpts Source #
Constructors
| FTCursorReadOpts | |
Fields | |
Instances
| Show FTCursorReadOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods showsPrec :: Int -> FTCursorReadOpts -> ShowS # show :: FTCursorReadOpts -> String # showList :: [FTCursorReadOpts] -> ShowS # | |
| Eq FTCursorReadOpts Source # | |
Defined in Database.Redis.ManualCommands.FT Methods (==) :: FTCursorReadOpts -> FTCursorReadOpts -> Bool # (/=) :: FTCursorReadOpts -> FTCursorReadOpts -> Bool # | |
countArgs :: [a] -> ByteString Source #
sortableToArgs :: FTSortable -> [ByteString] Source #
createFieldToArgs :: FTCreateField -> [ByteString] Source #
ftCreateOptsToArgs :: FTCreateOpts -> [ByteString] Source #
ftAlterOptsToArgs :: FTAlterOpts -> [ByteString] Source #
returnFieldToArgs :: FTReturnField -> [ByteString] Source #
geoFilterToArgs :: FTGeoFilter -> [ByteString] Source #
sortByToArgs :: FTSortBy -> [ByteString] Source #
ftSearchOptsToArgs :: FTSearchOpts -> [ByteString] Source #
reduceToArgs :: FTReduce -> [ByteString] Source #
groupByToArgs :: FTGroupBy -> [ByteString] Source #
applyToArgs :: FTApply -> [ByteString] Source #
cursorOptsToArgs :: FTCursorOpts -> [ByteString] Source #
hybridSortToArgs :: FTHybridSort -> [ByteString] Source #
hybridLoadToArgs :: FTHybridLoad -> [ByteString] Source #
ftHybridOptsToArgs :: FTHybridOpts -> [ByteString] Source #
ftSugAddOptsToArgs :: FTSugAddOpts -> [ByteString] Source #
ftList :: RedisCtx m f => m (f [ByteString]) Source #
Returns a list of all existing indexes (https://redis.io/commands/ft._list).
O(1)
Since RediSearch 2.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Index name. |
| -> ByteString | Query string. |
| -> m (f Reply) |
Run a search query on an index and perform aggregate transformations on the results (https://redis.io/commands/ft.aggregate).
The reply shape varies with options such as WITHCURSOR, so this wrapper returns the raw Reply.
O(1)
Since RediSearch 1.1.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Index name. |
| -> ByteString | Query string. |
| -> FTAggregateOpts | Aggregate options and transformation steps. |
| -> m (f Reply) |
Run a search query on an index and perform aggregate transformations on the results (https://redis.io/commands/ft.aggregate).
The reply shape varies with options such as WITHCURSOR, so this wrapper returns the raw Reply.
O(1)
Since RediSearch 1.1.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Alias name. |
| -> ByteString | Index name. |
| -> m (f Status) |
Arguments
| :: RedisCtx m f | |
| => ByteString | Alias name. |
| -> m (f Status) |
Arguments
| :: RedisCtx m f | |
| => ByteString | Alias name. |
| -> ByteString | Index name. |
| -> m (f Status) |
Adds or updates an alias to the index (https://redis.io/commands/ft.aliasupdate).
O(1)
Since RediSearch 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Index name. |
| -> FTCreateField | Field definition to append to the schema. |
| -> m (f Status) |
Adds a new field to the index (https://redis.io/commands/ft.alter).
O(N) where N is the number of keys in the keyspace
Since RediSearch 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Index name. |
| -> FTCreateField | Field definition to append to the schema. |
| -> FTAlterOpts | Alter options. |
| -> m (f Status) |
Adds a new field to the index (https://redis.io/commands/ft.alter).
O(N) where N is the number of keys in the keyspace
Since RediSearch 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Option name. |
| -> ByteString | Option value. |
| -> m (f Status) |
Sets runtime configuration options (https://redis.io/commands/ft.config-set).
O(1)
Since RediSearch 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Option name or pattern. |
| -> m (f Reply) |
Retrieves runtime configuration options (https://redis.io/commands/ft.config-get).
The server returns an option-dependent reply payload, so this wrapper returns the raw Reply.
O(1)
Since RediSearch 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Index name. |
| -> NonEmpty FTCreateField | Schema field definitions. |
| -> m (f Status) |
Creates an index with the given spec (https://redis.io/commands/ft.create).
O(K) at creation where K is the number of fields, O(N) if scanning the keyspace is triggered, where N is the number of keys in the keyspace
Since RediSearch 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Index name. |
| -> NonEmpty FTCreateField | Schema field definitions. |
| -> FTCreateOpts | Index creation options. |
| -> m (f Status) |
Creates an index with the given spec (https://redis.io/commands/ft.create).
O(K) at creation where K is the number of fields, O(N) if scanning the keyspace is triggered, where N is the number of keys in the keyspace
Since RediSearch 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Index name. |
| -> Integer | Cursor identifier. |
| -> m (f Status) |
Arguments
| :: RedisCtx m f | |
| => ByteString | Index name. |
| -> Integer | Cursor identifier. |
| -> m (f Reply) |
Reads from a cursor (https://redis.io/commands/ft.cursor-read).
The cursor batch payload is command-dependent, so this wrapper returns the raw Reply.
O(1)
Since RediSearch 1.1.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Index name. |
| -> Integer | Cursor identifier. |
| -> FTCursorReadOpts | Cursor read options. |
| -> m (f Reply) |
Reads from a cursor (https://redis.io/commands/ft.cursor-read).
The cursor batch payload is command-dependent, so this wrapper returns the raw Reply.
O(1)
Since RediSearch 1.1.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Dictionary name. |
| -> NonEmpty ByteString | Terms to add. |
| -> m (f Integer) |
Arguments
| :: RedisCtx m f | |
| => ByteString | Dictionary name. |
| -> NonEmpty ByteString | Terms to delete. |
| -> m (f Integer) |
Arguments
| :: RedisCtx m f | |
| => ByteString | Index name. |
| -> m (f Status) |
Deletes the index (https://redis.io/commands/ft.dropindex).
O(1) or O(N) if documents are deleted, where N is the number of keys in the keyspace
Since RediSearch 2.0.0
ftDropIndexDeleteDocs Source #
Arguments
| :: RedisCtx m f | |
| => ByteString | Index name. |
| -> m (f Status) |
Deletes the index (https://redis.io/commands/ft.dropindex).
This variant also deletes indexed documents.
O(1) or O(N) if documents are deleted, where N is the number of keys in the keyspace
Since RediSearch 2.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Index name. |
| -> ByteString | Query string. |
| -> m (f ByteString) |
Returns the execution plan for a complex query (https://redis.io/commands/ft.explain).
O(1)
Since RediSearch 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Index name. |
| -> ByteString | Query string. |
| -> FTExplainOpts | Explain options. |
| -> m (f ByteString) |
Returns the execution plan for a complex query (https://redis.io/commands/ft.explain).
O(1)
Since RediSearch 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Index name. |
| -> FTHybridSearchClause | Textual search clause. |
| -> FTHybridVSimClause | Vector similarity clause. |
| -> m (f Reply) |
Performs hybrid search combining text search and vector similarity with configurable fusion methods (https://redis.io/commands/ft.hybrid).
The reply shape depends on requested projections and scoring options, so this wrapper returns the raw Reply.
O(N)
Since Redis Open Source 8.4.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Index name. |
| -> FTHybridSearchClause | Textual search clause. |
| -> FTHybridVSimClause | Vector similarity clause. |
| -> FTHybridOpts | Hybrid query options. |
| -> m (f Reply) |
Performs hybrid search combining text search and vector similarity with configurable fusion methods (https://redis.io/commands/ft.hybrid).
The reply shape depends on requested projections and scoring options, so this wrapper returns the raw Reply.
O(N)
Since Redis Open Source 8.4.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Index name. |
| -> m (f Reply) |
Returns information and statistics on the index (https://redis.io/commands/ft.info).
The response is a heterogeneous attribute map, so this wrapper returns the raw Reply.
O(1)
Since RediSearch 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Index name. |
| -> FTProfileQueryType | Wrapped query type. |
| -> ByteString | Query payload for the wrapped command. |
| -> m (f Reply) |
Performs a SEARCH or AGGREGATE command and collects performance information (https://redis.io/commands/ft.profile).
The profiled reply depends on the wrapped query type, so this wrapper returns the raw Reply.
O(N)
Since RediSearch 2.2.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Index name. |
| -> FTProfileQueryType | Wrapped query type. |
| -> ByteString | Query payload for the wrapped command. |
| -> FTProfileOpts | Profiling options. |
| -> m (f Reply) |
Performs a SEARCH or AGGREGATE command and collects performance information (https://redis.io/commands/ft.profile).
The profiled reply depends on the wrapped query type, so this wrapper returns the raw Reply.
O(N)
Since RediSearch 2.2.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Index name. |
| -> ByteString | Query string. |
| -> m (f Reply) |
Searches the index with a textual query, returning either documents or just ids (https://redis.io/commands/ft.search).
The reply shape depends on output flags such as NOCONTENT and WITHSCORES, so this wrapper returns the raw Reply.
O(N)
Since RediSearch 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Index name. |
| -> ByteString | Query string. |
| -> FTSearchOpts | Search options. |
| -> m (f Reply) |
Searches the index with a textual query, returning either documents or just ids (https://redis.io/commands/ft.search).
The reply shape depends on output flags such as NOCONTENT and WITHSCORES, so this wrapper returns the raw Reply.
O(N)
Since RediSearch 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Index name. |
| -> ByteString | Query string. |
| -> m (f Reply) |
Performs spelling correction on a query, returning suggestions for misspelled terms (https://redis.io/commands/ft.spellcheck).
The response contains nested suggestions, so this wrapper returns the raw Reply.
O(1)
Since RediSearch 1.4.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Index name. |
| -> ByteString | Query string. |
| -> FTSpellcheckOpts | Spellcheck options. |
| -> m (f Reply) |
Performs spelling correction on a query, returning suggestions for misspelled terms (https://redis.io/commands/ft.spellcheck).
The response contains nested suggestions, so this wrapper returns the raw Reply.
O(1)
Since RediSearch 1.4.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Suggestion dictionary key. |
| -> ByteString | Suggestion string. |
| -> Double | Suggestion score. |
| -> m (f Integer) |
Adds a suggestion string to an auto-complete suggestion dictionary (https://redis.io/commands/ft.sugadd).
O(1)
Since RediSearch 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Suggestion dictionary key. |
| -> ByteString | Suggestion string. |
| -> Double | Suggestion score. |
| -> FTSugAddOpts | Suggestion insertion options. |
| -> m (f Integer) |
Adds a suggestion string to an auto-complete suggestion dictionary (https://redis.io/commands/ft.sugadd).
O(1)
Since RediSearch 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Suggestion dictionary key. |
| -> ByteString | Suggestion string. |
| -> m (f Integer) |
Deletes a string from a suggestion index (https://redis.io/commands/ft.sugdel).
O(1)
Since RediSearch 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Suggestion dictionary key. |
| -> m (f Integer) |
Gets the size of an auto-complete suggestion dictionary (https://redis.io/commands/ft.suglen).
O(1)
Since RediSearch 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Index name. |
| -> ByteString | Tag field name. |
| -> m (f [ByteString]) |
Returns the distinct tags indexed in a Tag field (https://redis.io/commands/ft.tagvals).
O(n) where n is the number of distinct tags in the field
Since RediSearch 1.0.0