| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Database.Redis.ManualCommands.JSON
Synopsis
- data JSONGetOpts = JSONGetOpts {}
- defaultJSONGetOpts :: JSONGetOpts
- data JSONSetCondition
- data JSONSetFPHA
- data JSONSetOpts = JSONSetOpts {}
- defaultJSONSetOpts :: JSONSetOpts
- data JSONArrIndexOpts
- defaultJSONArrIndexOpts :: JSONArrIndexOpts
- jsonGetOptsToArgs :: JSONGetOpts -> [ByteString]
- jsonSetOptsToArgs :: JSONSetOpts -> [ByteString]
- jsonArrIndexOptsToArgs :: JSONArrIndexOpts -> [ByteString]
- jsonArrappend :: RedisCtx m f => ByteString -> ByteString -> NonEmpty ByteString -> m (f Reply)
- jsonArrindex :: RedisCtx m f => ByteString -> ByteString -> ByteString -> m (f Reply)
- jsonArrindexOpts :: RedisCtx m f => ByteString -> ByteString -> ByteString -> JSONArrIndexOpts -> m (f Reply)
- jsonArrlen :: RedisCtx m f => ByteString -> m (f Reply)
- jsonArrlenAt :: RedisCtx m f => ByteString -> ByteString -> m (f Reply)
- jsonArrinsert :: RedisCtx m f => ByteString -> ByteString -> Integer -> NonEmpty ByteString -> m (f Reply)
- jsonArrpop :: RedisCtx m f => ByteString -> m (f Reply)
- jsonArrpopAt :: RedisCtx m f => ByteString -> ByteString -> m (f Reply)
- jsonArrpopAtIndex :: RedisCtx m f => ByteString -> ByteString -> Integer -> m (f Reply)
- jsonArrtrim :: RedisCtx m f => ByteString -> ByteString -> Integer -> Integer -> m (f Reply)
- jsonClear :: RedisCtx m f => ByteString -> m (f Integer)
- jsonClearAt :: RedisCtx m f => ByteString -> ByteString -> m (f Integer)
- jsonDebug :: RedisCtx m f => m (f Reply)
- jsonDebugMemory :: RedisCtx m f => ByteString -> m (f Reply)
- jsonDebugMemoryAt :: RedisCtx m f => ByteString -> ByteString -> m (f Reply)
- jsonDel :: RedisCtx m f => ByteString -> m (f Integer)
- jsonDelAt :: RedisCtx m f => ByteString -> ByteString -> m (f Integer)
- jsonForget :: RedisCtx m f => ByteString -> m (f Integer)
- jsonForgetAt :: RedisCtx m f => ByteString -> ByteString -> m (f Integer)
- jsonGet :: RedisCtx m f => ByteString -> m (f (Maybe ByteString))
- jsonGetOpts :: RedisCtx m f => ByteString -> JSONGetOpts -> m (f (Maybe ByteString))
- jsonMerge :: RedisCtx m f => ByteString -> ByteString -> ByteString -> m (f Status)
- jsonMget :: RedisCtx m f => NonEmpty ByteString -> ByteString -> m (f [Maybe ByteString])
- jsonMset :: RedisCtx m f => NonEmpty (ByteString, ByteString, ByteString) -> m (f Status)
- jsonNumincrby :: RedisCtx m f => ByteString -> ByteString -> Double -> m (f Reply)
- jsonNummultby :: RedisCtx m f => ByteString -> ByteString -> Double -> m (f Reply)
- jsonObjkeys :: RedisCtx m f => ByteString -> m (f Reply)
- jsonObjkeysAt :: RedisCtx m f => ByteString -> ByteString -> m (f Reply)
- jsonObjlen :: RedisCtx m f => ByteString -> m (f Reply)
- jsonObjlenAt :: RedisCtx m f => ByteString -> ByteString -> m (f Reply)
- jsonResp :: RedisCtx m f => ByteString -> m (f Reply)
- jsonRespAt :: RedisCtx m f => ByteString -> ByteString -> m (f Reply)
- jsonSet :: RedisCtx m f => ByteString -> ByteString -> ByteString -> m (f (Maybe Status))
- jsonSetOpts :: RedisCtx m f => ByteString -> ByteString -> ByteString -> JSONSetOpts -> m (f (Maybe Status))
- jsonStrappend :: RedisCtx m f => ByteString -> ByteString -> m (f Reply)
- jsonStrappendAt :: RedisCtx m f => ByteString -> ByteString -> ByteString -> m (f Reply)
- jsonToggle :: RedisCtx m f => ByteString -> ByteString -> m (f Reply)
- jsonType :: RedisCtx m f => ByteString -> m (f Reply)
- jsonTypeAt :: RedisCtx m f => ByteString -> ByteString -> m (f Reply)
Documentation
data JSONGetOpts Source #
Constructors
| JSONGetOpts | |
Fields | |
Instances
| Show JSONGetOpts Source # | |
Defined in Database.Redis.ManualCommands.JSON Methods showsPrec :: Int -> JSONGetOpts -> ShowS # show :: JSONGetOpts -> String # showList :: [JSONGetOpts] -> ShowS # | |
| Eq JSONGetOpts Source # | |
Defined in Database.Redis.ManualCommands.JSON | |
data JSONSetCondition Source #
Constructors
| JSONSetIfNotExists | |
| JSONSetIfExists |
Instances
| Show JSONSetCondition Source # | |
Defined in Database.Redis.ManualCommands.JSON Methods showsPrec :: Int -> JSONSetCondition -> ShowS # show :: JSONSetCondition -> String # showList :: [JSONSetCondition] -> ShowS # | |
| Eq JSONSetCondition Source # | |
Defined in Database.Redis.ManualCommands.JSON Methods (==) :: JSONSetCondition -> JSONSetCondition -> Bool # (/=) :: JSONSetCondition -> JSONSetCondition -> Bool # | |
| RedisArg JSONSetCondition Source # | |
Defined in Database.Redis.ManualCommands.JSON Methods encode :: JSONSetCondition -> ByteString Source # | |
data JSONSetFPHA Source #
Constructors
| JSONSetFP16 | |
| JSONSetBF16 | |
| JSONSetFP32 | |
| JSONSetFP64 |
Instances
| Show JSONSetFPHA Source # | |
Defined in Database.Redis.ManualCommands.JSON Methods showsPrec :: Int -> JSONSetFPHA -> ShowS # show :: JSONSetFPHA -> String # showList :: [JSONSetFPHA] -> ShowS # | |
| Eq JSONSetFPHA Source # | |
Defined in Database.Redis.ManualCommands.JSON | |
| RedisArg JSONSetFPHA Source # | |
Defined in Database.Redis.ManualCommands.JSON Methods encode :: JSONSetFPHA -> ByteString Source # | |
data JSONSetOpts Source #
Constructors
| JSONSetOpts | |
Fields | |
Instances
| Show JSONSetOpts Source # | |
Defined in Database.Redis.ManualCommands.JSON Methods showsPrec :: Int -> JSONSetOpts -> ShowS # show :: JSONSetOpts -> String # showList :: [JSONSetOpts] -> ShowS # | |
| Eq JSONSetOpts Source # | |
Defined in Database.Redis.ManualCommands.JSON | |
data JSONArrIndexOpts Source #
Instances
| Show JSONArrIndexOpts Source # | |
Defined in Database.Redis.ManualCommands.JSON Methods showsPrec :: Int -> JSONArrIndexOpts -> ShowS # show :: JSONArrIndexOpts -> String # showList :: [JSONArrIndexOpts] -> ShowS # | |
| Eq JSONArrIndexOpts Source # | |
Defined in Database.Redis.ManualCommands.JSON Methods (==) :: JSONArrIndexOpts -> JSONArrIndexOpts -> Bool # (/=) :: JSONArrIndexOpts -> JSONArrIndexOpts -> Bool # | |
jsonGetOptsToArgs :: JSONGetOpts -> [ByteString] Source #
jsonSetOptsToArgs :: JSONSetOpts -> [ByteString] Source #
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> ByteString | Path to the array. |
| -> NonEmpty ByteString | Serialized JSON values to append. |
| -> m (f Reply) |
Appends one or more JSON values into the array at path after the last element in it (https://redis.io/commands/json.arrappend).
The reply shape depends on the path syntax, so this wrapper returns the raw Reply.
O(1) when path is evaluated to a single value, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> ByteString | Path to the array. |
| -> ByteString | Serialized JSON scalar to search for. |
| -> m (f Reply) |
Returns the index of the first occurrence of a JSON scalar value in the array at path (https://redis.io/commands/json.arrindex).
The reply shape depends on the path syntax, so this wrapper returns the raw Reply.
O(N) when path is evaluated to a single value where N is the size of the array, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> ByteString | Path to the array. |
| -> ByteString | Serialized JSON scalar to search for. |
| -> JSONArrIndexOpts | Optional search range. |
| -> m (f Reply) |
Returns the index of the first occurrence of a JSON scalar value in the array at path (https://redis.io/commands/json.arrindex).
The reply shape depends on the path syntax, so this wrapper returns the raw Reply.
O(N) when path is evaluated to a single value where N is the size of the array, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> m (f Reply) |
Returns the length of the array at the root path (https://redis.io/commands/json.arrlen).
O(1) where path is evaluated to a single value, O(N) where path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> ByteString | Path to the array. |
| -> m (f Reply) |
Returns the length of the array at path (https://redis.io/commands/json.arrlen).
The reply shape depends on the path syntax, so this wrapper returns the raw Reply.
O(1) where path is evaluated to a single value, O(N) where path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> ByteString | Path to the array. |
| -> Integer | Insertion index. |
| -> NonEmpty ByteString | Serialized JSON values to insert. |
| -> m (f Reply) |
Inserts the JSON scalar(s) value at the specified index in the array at path (https://redis.io/commands/json.arrinsert).
The reply shape depends on the path syntax, so this wrapper returns the raw Reply.
O(N) when path is evaluated to a single value where N is the size of the array, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> m (f Reply) |
Removes and returns the element at the end of the array at the root path (https://redis.io/commands/json.arrpop).
O(1) when the popped item is the last element, otherwise O(N) where N is the size of the array
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> ByteString | Path to the array. |
| -> m (f Reply) |
Removes and returns the element at the end of the array at path (https://redis.io/commands/json.arrpop).
The reply shape depends on the path syntax and popped value type, so this wrapper returns the raw Reply.
O(1) when the popped item is the last element, otherwise O(N) where N is the size of the array
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> ByteString | Path to the array. |
| -> Integer | Index to pop. |
| -> m (f Reply) |
Removes and returns the element at the specified index in the array at path (https://redis.io/commands/json.arrpop).
The reply shape depends on the path syntax and popped value type, so this wrapper returns the raw Reply.
O(N) when the specified index is not the last element, otherwise O(1)
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> ByteString | Path to the array. |
| -> Integer | Start index. |
| -> Integer | Stop index. |
| -> m (f Reply) |
Trims the array at path to contain only the specified inclusive range of indices from start to stop (https://redis.io/commands/json.arrtrim).
The reply shape depends on the path syntax, so this wrapper returns the raw Reply.
O(N) when path is evaluated to a single value where N is the size of the array, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> m (f Integer) |
Clears all values from an array or an object and sets numeric values at the root path to 0 (https://redis.io/commands/json.clear).
O(N) when path is evaluated to a single value where N is the size of the values, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 2.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> ByteString | Path to clear. |
| -> m (f Integer) |
Clears all values from an array or an object and sets numeric values at path to 0 (https://redis.io/commands/json.clear).
O(N) when path is evaluated to a single value where N is the size of the values, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 2.0.0
jsonDebug :: RedisCtx m f => m (f Reply) Source #
Executes the JSON debug container command (https://redis.io/commands/json.debug).
This is a container command for debugging related tasks.
N/A
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> m (f Reply) |
Reports the size in bytes of a key at the root path (https://redis.io/commands/json.debug-memory).
The reply shape depends on the path syntax, so this wrapper returns the raw Reply.
O(N) when path is evaluated to a single value, where N is the size of the value, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> ByteString | Path to inspect. |
| -> m (f Reply) |
Reports the size in bytes of a key at path (https://redis.io/commands/json.debug-memory).
The reply shape depends on the path syntax, so this wrapper returns the raw Reply.
O(N) when path is evaluated to a single value, where N is the size of the value, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> m (f Integer) |
Deletes a value at the root path (https://redis.io/commands/json.del).
O(N) when path is evaluated to a single value where N is the size of the deleted value, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> ByteString | Path to delete. |
| -> m (f Integer) |
Deletes a value at path (https://redis.io/commands/json.del).
O(N) when path is evaluated to a single value where N is the size of the deleted value, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> m (f Integer) |
Deletes a value at the root path (https://redis.io/commands/json.forget).
O(N) when path is evaluated to a single value where N is the size of the deleted value, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> ByteString | Path to delete. |
| -> m (f Integer) |
Deletes a value at path (https://redis.io/commands/json.forget).
O(N) when path is evaluated to a single value where N is the size of the deleted value, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> m (f (Maybe ByteString)) |
Gets the value at the root path in JSON serialized form (https://redis.io/commands/json.get).
O(N) when path is evaluated to a single value where N is the size of the value, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> JSONGetOpts | Formatting and path selection options. |
| -> m (f (Maybe ByteString)) |
Gets the value at one or more paths in JSON serialized form (https://redis.io/commands/json.get).
O(N) when path is evaluated to a single value where N is the size of the value, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> ByteString | Path to merge into. |
| -> ByteString | Serialized JSON value. |
| -> m (f Status) |
Merges a given JSON value into matching paths (https://redis.io/commands/json.merge).
Consequently, JSON values at matching paths are updated, deleted, or expanded with new children.
O(M+N) when path is evaluated to a single value where M is the size of the original value and N is the size of the new value, O(M+N) when path is evaluated to multiple values where M is the size of the key and N is the size of the new value times the number of matches
Since RedisJSON 2.6.0
Arguments
| :: RedisCtx m f | |
| => NonEmpty ByteString | Keys holding JSON values. |
| -> ByteString | Path to fetch from each key. |
| -> m (f [Maybe ByteString]) |
Returns the values at a path from one or more keys (https://redis.io/commands/json.mget).
O(M*N) when path is evaluated to a single value where M is the number of keys and N is the size of the value, O(N1+N2+dots+Nm) when path is evaluated to multiple values
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => NonEmpty (ByteString, ByteString, ByteString) | Key, path, serialized JSON value triplets. |
| -> m (f Status) |
Sets or updates the JSON value of one or more keys (https://redis.io/commands/json.mset).
O(K*(M+N)) where K is the number of keys in the command
Since RedisJSON 2.6.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> ByteString | Path to the numeric value. |
| -> Double | Increment value. |
| -> m (f Reply) |
Increments the numeric value at path by a value (https://redis.io/commands/json.numincrby).
The reply shape depends on the path syntax, so this wrapper returns the raw Reply.
O(1) when path is evaluated to a single value, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> ByteString | Path to the numeric value. |
| -> Double | Multiplier value. |
| -> m (f Reply) |
Multiplies the numeric value at path by a value (https://redis.io/commands/json.nummultby).
The reply shape depends on the path syntax, so this wrapper returns the raw Reply.
O(1) when path is evaluated to a single value, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> m (f Reply) |
Returns the key names of JSON objects at the root path (https://redis.io/commands/json.objkeys).
The reply shape depends on the path syntax, so this wrapper returns the raw Reply.
O(N) when path is evaluated to a single value, where N is the number of keys in the object, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> ByteString | Path to the object. |
| -> m (f Reply) |
Returns the key names of JSON objects at path (https://redis.io/commands/json.objkeys).
The reply shape depends on the path syntax, so this wrapper returns the raw Reply.
O(N) when path is evaluated to a single value, where N is the number of keys in the object, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> m (f Reply) |
Returns the number of keys in JSON objects at the root path (https://redis.io/commands/json.objlen).
The reply shape depends on the path syntax, so this wrapper returns the raw Reply.
O(1) when path is evaluated to a single value, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> ByteString | Path to the object. |
| -> m (f Reply) |
Returns the number of keys in JSON objects at path (https://redis.io/commands/json.objlen).
The reply shape depends on the path syntax, so this wrapper returns the raw Reply.
O(1) when path is evaluated to a single value, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> m (f Reply) |
Returns the JSON value at the root path in Redis Serialization Protocol (RESP) (https://redis.io/commands/json.resp).
The reply may be any RESP shape depending on the JSON value, so this wrapper returns the raw Reply.
O(N) when path is evaluated to a single value, where N is the size of the value, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> ByteString | Path to inspect. |
| -> m (f Reply) |
Returns the JSON value at path in Redis Serialization Protocol (RESP) (https://redis.io/commands/json.resp).
The reply may be any RESP shape depending on the JSON value, so this wrapper returns the raw Reply.
O(N) when path is evaluated to a single value, where N is the size of the value, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 1.0.0
when path is evaluated to a single value where $M$ is the size of the original value and $N$ is the size of the new value, $O(M+N)$ when path is evaluated to multiple values where $M$ is the size of the key and $N$ is the size of the new value times the number of matches
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> ByteString | Path to set. |
| -> ByteString | Serialized JSON value. |
| -> m (f (Maybe Status)) |
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> ByteString | Path to set. |
| -> ByteString | Serialized JSON value. |
| -> JSONSetOpts | Conditional and FPHA options. |
| -> m (f (Maybe Status)) |
Sets or updates the JSON value at a path (https://redis.io/commands/json.set).
O(M+N) when path is evaluated to a single value where M is the size of the original value and N is the size of the new value, O(M+N) when path is evaluated to multiple values where M is the size of the key and N is the size of the new value times the number of matches
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> ByteString | String value to append. |
| -> m (f Reply) |
Appends a string to JSON strings at the root path (https://redis.io/commands/json.strappend).
The reply shape depends on the path syntax, so this wrapper returns the raw Reply.
O(1) when path is evaluated to a single value, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> ByteString | Path to the JSON string. |
| -> ByteString | String value to append. |
| -> m (f Reply) |
Appends a string to JSON strings at path (https://redis.io/commands/json.strappend).
The reply shape depends on the path syntax, so this wrapper returns the raw Reply.
O(1) when path is evaluated to a single value, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> ByteString | Path to the boolean value. |
| -> m (f Reply) |
Toggles a boolean value (https://redis.io/commands/json.toggle).
The reply shape depends on the path syntax, so this wrapper returns the raw Reply.
O(1) when path is evaluated to a single value, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 2.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> m (f Reply) |
Returns the type of the JSON value at the root path (https://redis.io/commands/json.type).
The reply shape depends on the path syntax, so this wrapper returns the raw Reply.
O(1) when path is evaluated to a single value, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Key holding a JSON value. |
| -> ByteString | Path to inspect. |
| -> m (f Reply) |
Returns the type of the JSON value at path (https://redis.io/commands/json.type).
The reply shape depends on the path syntax, so this wrapper returns the raw Reply.
O(1) when path is evaluated to a single value, O(N) when path is evaluated to multiple values, where N is the size of the key
Since RedisJSON 1.0.0