| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Database.Redis.ManualCommands.Ts
Synopsis
- data TsSample = TsSample {}
- data TsEncoding
- data TsDuplicatePolicy
- data TsIgnore = TsIgnore {}
- data TsCreateOpts = TsCreateOpts {}
- defaultTsCreateOpts :: TsCreateOpts
- data TsAlterOpts = TsAlterOpts {}
- defaultTsAlterOpts :: TsAlterOpts
- data TsAddOpts = TsAddOpts {}
- defaultTsAddOpts :: TsAddOpts
- data TsIncrByOpts = TsIncrByOpts {}
- defaultTsIncrByOpts :: TsIncrByOpts
- data TsGetOpts = TsGetOpts {
- tsGetLatest :: Bool
- defaultTsGetOpts :: TsGetOpts
- data TsAggregator
- newtype TsAggregators = TsAggregators {}
- data TsBucketTimestamp
- data TsAggregationOpts = TsAggregationOpts {}
- data TsRangeOpts = TsRangeOpts {}
- defaultTsRangeOpts :: TsRangeOpts
- data TsLabelSelection
- data TsGroupByReduce = TsGroupByReduce {}
- data TsMGetOpts = TsMGetOpts {}
- defaultTsMGetOpts :: TsMGetOpts
- data TsMRangeOpts = TsMRangeOpts {}
- defaultTsMRangeOpts :: TsMRangeOpts
- data TsInfoOpts
- tsLabelsToArgs :: [(ByteString, ByteString)] -> [ByteString]
- tsIgnoreToArgs :: TsIgnore -> [ByteString]
- tsCreateOptsToArgs :: TsCreateOpts -> [ByteString]
- tsAlterOptsToArgs :: TsAlterOpts -> [ByteString]
- tsAddOptsToArgs :: TsAddOpts -> [ByteString]
- tsIncrByOptsToArgs :: TsIncrByOpts -> [ByteString]
- tsAggregationToArgs :: TsAggregationOpts -> [ByteString]
- tsRangeOptsToArgs :: TsRangeOpts -> [ByteString]
- tsLabelSelectionToArgs :: TsLabelSelection -> [ByteString]
- tsMGetOptsToArgs :: TsMGetOpts -> [ByteString]
- tsGroupByReduceToArgs :: TsGroupByReduce -> [ByteString]
- tsMRangeOptsToArgs :: TsMRangeOpts -> [ByteString]
- tsAdd :: RedisCtx m f => ByteString -> ByteString -> Double -> m (f Integer)
- tsAddOpts :: RedisCtx m f => ByteString -> ByteString -> Double -> TsAddOpts -> m (f Integer)
- tsAlter :: RedisCtx m f => ByteString -> TsAlterOpts -> m (f Status)
- tsCreate :: RedisCtx m f => ByteString -> m (f Status)
- tsCreateOpts :: RedisCtx m f => ByteString -> TsCreateOpts -> m (f Status)
- tsCreaterule :: RedisCtx m f => ByteString -> ByteString -> TsAggregator -> Integer -> m (f Status)
- tsCreateruleAlign :: RedisCtx m f => ByteString -> ByteString -> TsAggregator -> Integer -> Integer -> m (f Status)
- tsDecrby :: RedisCtx m f => ByteString -> Double -> m (f Integer)
- tsDecrbyOpts :: RedisCtx m f => ByteString -> Double -> TsIncrByOpts -> m (f Integer)
- tsDel :: RedisCtx m f => ByteString -> Integer -> Integer -> m (f Integer)
- tsDelrule :: RedisCtx m f => ByteString -> ByteString -> m (f Status)
- tsGet :: RedisCtx m f => ByteString -> m (f (Maybe TsSample))
- tsGetOpts :: RedisCtx m f => ByteString -> TsGetOpts -> m (f (Maybe TsSample))
- tsIncrby :: RedisCtx m f => ByteString -> Double -> m (f Integer)
- tsIncrbyOpts :: RedisCtx m f => ByteString -> Double -> TsIncrByOpts -> m (f Integer)
- tsInfo :: RedisCtx m f => ByteString -> m (f Reply)
- tsInfoOpts :: RedisCtx m f => ByteString -> TsInfoOpts -> m (f Reply)
- tsMadd :: RedisCtx m f => NonEmpty (ByteString, ByteString, Double) -> m (f [Integer])
- tsMget :: RedisCtx m f => NonEmpty ByteString -> m (f Reply)
- tsMgetOpts :: RedisCtx m f => NonEmpty ByteString -> TsMGetOpts -> m (f Reply)
- tsMrange :: RedisCtx m f => ByteString -> ByteString -> NonEmpty ByteString -> m (f Reply)
- tsMrangeOpts :: RedisCtx m f => ByteString -> ByteString -> NonEmpty ByteString -> TsMRangeOpts -> m (f Reply)
- tsMrevrange :: RedisCtx m f => ByteString -> ByteString -> NonEmpty ByteString -> m (f Reply)
- tsMrevrangeOpts :: RedisCtx m f => ByteString -> ByteString -> NonEmpty ByteString -> TsMRangeOpts -> m (f Reply)
- tsQueryindex :: RedisCtx m f => NonEmpty ByteString -> m (f [ByteString])
- tsRange :: RedisCtx m f => ByteString -> ByteString -> ByteString -> m (f [TsSample])
- tsRangeOpts :: RedisCtx m f => ByteString -> ByteString -> ByteString -> TsRangeOpts -> m (f [TsSample])
- tsRevrange :: RedisCtx m f => ByteString -> ByteString -> ByteString -> m (f [TsSample])
- tsRevrangeOpts :: RedisCtx m f => ByteString -> ByteString -> ByteString -> TsRangeOpts -> m (f [TsSample])
Documentation
Constructors
| TsSample | |
Fields | |
data TsEncoding Source #
Constructors
| TsUncompressed | |
| TsCompressed |
Instances
| Show TsEncoding Source # | |
Defined in Database.Redis.ManualCommands.Ts Methods showsPrec :: Int -> TsEncoding -> ShowS # show :: TsEncoding -> String # showList :: [TsEncoding] -> ShowS # | |
| Eq TsEncoding Source # | |
Defined in Database.Redis.ManualCommands.Ts | |
| RedisArg TsEncoding Source # | |
Defined in Database.Redis.ManualCommands.Ts Methods encode :: TsEncoding -> ByteString Source # | |
data TsDuplicatePolicy Source #
Constructors
| TsDuplicateBlock | |
| TsDuplicateFirst | |
| TsDuplicateLast | |
| TsDuplicateMin | |
| TsDuplicateMax | |
| TsDuplicateSum |
Instances
| Show TsDuplicatePolicy Source # | |
Defined in Database.Redis.ManualCommands.Ts Methods showsPrec :: Int -> TsDuplicatePolicy -> ShowS # show :: TsDuplicatePolicy -> String # showList :: [TsDuplicatePolicy] -> ShowS # | |
| Eq TsDuplicatePolicy Source # | |
Defined in Database.Redis.ManualCommands.Ts Methods (==) :: TsDuplicatePolicy -> TsDuplicatePolicy -> Bool # (/=) :: TsDuplicatePolicy -> TsDuplicatePolicy -> Bool # | |
| RedisArg TsDuplicatePolicy Source # | |
Defined in Database.Redis.ManualCommands.Ts Methods encode :: TsDuplicatePolicy -> ByteString Source # | |
data TsCreateOpts Source #
Constructors
| TsCreateOpts | |
Instances
| Show TsCreateOpts Source # | |
Defined in Database.Redis.ManualCommands.Ts Methods showsPrec :: Int -> TsCreateOpts -> ShowS # show :: TsCreateOpts -> String # showList :: [TsCreateOpts] -> ShowS # | |
| Eq TsCreateOpts Source # | |
Defined in Database.Redis.ManualCommands.Ts | |
data TsAlterOpts Source #
Constructors
| TsAlterOpts | |
Fields | |
Instances
| Show TsAlterOpts Source # | |
Defined in Database.Redis.ManualCommands.Ts Methods showsPrec :: Int -> TsAlterOpts -> ShowS # show :: TsAlterOpts -> String # showList :: [TsAlterOpts] -> ShowS # | |
| Eq TsAlterOpts Source # | |
Defined in Database.Redis.ManualCommands.Ts | |
data TsIncrByOpts Source #
Constructors
| TsIncrByOpts | |
Instances
| Show TsIncrByOpts Source # | |
Defined in Database.Redis.ManualCommands.Ts Methods showsPrec :: Int -> TsIncrByOpts -> ShowS # show :: TsIncrByOpts -> String # showList :: [TsIncrByOpts] -> ShowS # | |
| Eq TsIncrByOpts Source # | |
Defined in Database.Redis.ManualCommands.Ts | |
Constructors
| TsGetOpts | |
Fields
| |
data TsAggregator Source #
Constructors
| TsAggAvg | |
| TsAggFirst | |
| TsAggLast | |
| TsAggMin | |
| TsAggMax | |
| TsAggSum | |
| TsAggRange | |
| TsAggCount | |
| TsAggStdP | |
| TsAggStdS | |
| TsAggVarP | |
| TsAggVarS | |
| TsAggTwa | |
| TsAggCountNaN | |
| TsAggCountAll |
Instances
| Show TsAggregator Source # | |
Defined in Database.Redis.ManualCommands.Ts Methods showsPrec :: Int -> TsAggregator -> ShowS # show :: TsAggregator -> String # showList :: [TsAggregator] -> ShowS # | |
| Eq TsAggregator Source # | |
Defined in Database.Redis.ManualCommands.Ts | |
| RedisArg TsAggregator Source # | |
Defined in Database.Redis.ManualCommands.Ts Methods encode :: TsAggregator -> ByteString Source # | |
newtype TsAggregators Source #
Constructors
| TsAggregators | |
Fields | |
Instances
| Show TsAggregators Source # | |
Defined in Database.Redis.ManualCommands.Ts Methods showsPrec :: Int -> TsAggregators -> ShowS # show :: TsAggregators -> String # showList :: [TsAggregators] -> ShowS # | |
| Eq TsAggregators Source # | |
Defined in Database.Redis.ManualCommands.Ts Methods (==) :: TsAggregators -> TsAggregators -> Bool # (/=) :: TsAggregators -> TsAggregators -> Bool # | |
| RedisArg TsAggregators Source # | |
Defined in Database.Redis.ManualCommands.Ts Methods encode :: TsAggregators -> ByteString Source # | |
data TsBucketTimestamp Source #
Constructors
| TsBucketStart | |
| TsBucketEnd | |
| TsBucketMid |
Instances
| Show TsBucketTimestamp Source # | |
Defined in Database.Redis.ManualCommands.Ts Methods showsPrec :: Int -> TsBucketTimestamp -> ShowS # show :: TsBucketTimestamp -> String # showList :: [TsBucketTimestamp] -> ShowS # | |
| Eq TsBucketTimestamp Source # | |
Defined in Database.Redis.ManualCommands.Ts Methods (==) :: TsBucketTimestamp -> TsBucketTimestamp -> Bool # (/=) :: TsBucketTimestamp -> TsBucketTimestamp -> Bool # | |
| RedisArg TsBucketTimestamp Source # | |
Defined in Database.Redis.ManualCommands.Ts Methods encode :: TsBucketTimestamp -> ByteString Source # | |
data TsAggregationOpts Source #
Constructors
| TsAggregationOpts | |
Instances
| Show TsAggregationOpts Source # | |
Defined in Database.Redis.ManualCommands.Ts Methods showsPrec :: Int -> TsAggregationOpts -> ShowS # show :: TsAggregationOpts -> String # showList :: [TsAggregationOpts] -> ShowS # | |
| Eq TsAggregationOpts Source # | |
Defined in Database.Redis.ManualCommands.Ts Methods (==) :: TsAggregationOpts -> TsAggregationOpts -> Bool # (/=) :: TsAggregationOpts -> TsAggregationOpts -> Bool # | |
data TsRangeOpts Source #
Constructors
| TsRangeOpts | |
Fields | |
Instances
| Show TsRangeOpts Source # | |
Defined in Database.Redis.ManualCommands.Ts Methods showsPrec :: Int -> TsRangeOpts -> ShowS # show :: TsRangeOpts -> String # showList :: [TsRangeOpts] -> ShowS # | |
| Eq TsRangeOpts Source # | |
Defined in Database.Redis.ManualCommands.Ts | |
data TsLabelSelection Source #
Constructors
| TsWithLabels | |
| TsSelectedLabels (NonEmpty ByteString) |
Instances
| Show TsLabelSelection Source # | |
Defined in Database.Redis.ManualCommands.Ts Methods showsPrec :: Int -> TsLabelSelection -> ShowS # show :: TsLabelSelection -> String # showList :: [TsLabelSelection] -> ShowS # | |
| Eq TsLabelSelection Source # | |
Defined in Database.Redis.ManualCommands.Ts Methods (==) :: TsLabelSelection -> TsLabelSelection -> Bool # (/=) :: TsLabelSelection -> TsLabelSelection -> Bool # | |
data TsGroupByReduce Source #
Constructors
| TsGroupByReduce | |
Fields | |
Instances
| Show TsGroupByReduce Source # | |
Defined in Database.Redis.ManualCommands.Ts Methods showsPrec :: Int -> TsGroupByReduce -> ShowS # show :: TsGroupByReduce -> String # showList :: [TsGroupByReduce] -> ShowS # | |
| Eq TsGroupByReduce Source # | |
Defined in Database.Redis.ManualCommands.Ts Methods (==) :: TsGroupByReduce -> TsGroupByReduce -> Bool # (/=) :: TsGroupByReduce -> TsGroupByReduce -> Bool # | |
data TsMGetOpts Source #
Constructors
| TsMGetOpts | |
Fields | |
Instances
| Show TsMGetOpts Source # | |
Defined in Database.Redis.ManualCommands.Ts Methods showsPrec :: Int -> TsMGetOpts -> ShowS # show :: TsMGetOpts -> String # showList :: [TsMGetOpts] -> ShowS # | |
| Eq TsMGetOpts Source # | |
Defined in Database.Redis.ManualCommands.Ts | |
data TsMRangeOpts Source #
Constructors
| TsMRangeOpts | |
Instances
| Show TsMRangeOpts Source # | |
Defined in Database.Redis.ManualCommands.Ts Methods showsPrec :: Int -> TsMRangeOpts -> ShowS # show :: TsMRangeOpts -> String # showList :: [TsMRangeOpts] -> ShowS # | |
| Eq TsMRangeOpts Source # | |
Defined in Database.Redis.ManualCommands.Ts | |
data TsInfoOpts Source #
Constructors
| TsInfoDefault | |
| TsInfoDebug |
Instances
| Show TsInfoOpts Source # | |
Defined in Database.Redis.ManualCommands.Ts Methods showsPrec :: Int -> TsInfoOpts -> ShowS # show :: TsInfoOpts -> String # showList :: [TsInfoOpts] -> ShowS # | |
| Eq TsInfoOpts Source # | |
Defined in Database.Redis.ManualCommands.Ts | |
tsLabelsToArgs :: [(ByteString, ByteString)] -> [ByteString] Source #
tsIgnoreToArgs :: TsIgnore -> [ByteString] Source #
tsCreateOptsToArgs :: TsCreateOpts -> [ByteString] Source #
tsAlterOptsToArgs :: TsAlterOpts -> [ByteString] Source #
tsAddOptsToArgs :: TsAddOpts -> [ByteString] Source #
tsIncrByOptsToArgs :: TsIncrByOpts -> [ByteString] Source #
tsRangeOptsToArgs :: TsRangeOpts -> [ByteString] Source #
tsMGetOptsToArgs :: TsMGetOpts -> [ByteString] Source #
tsMRangeOptsToArgs :: TsMRangeOpts -> [ByteString] Source #
Arguments
| :: RedisCtx m f | |
| => ByteString | Time series key. |
| -> ByteString | Timestamp, or |
| -> Double | Sample value. |
| -> m (f Integer) |
Appends a sample to a time series (https://redis.io/commands/ts.add).
O(M) when M is the number of compaction rules, or O(1) with no compaction
Since RedisTimeSeries 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Time series key. |
| -> ByteString | Timestamp, or |
| -> Double | Sample value. |
| -> TsAddOpts | Insertion options. |
| -> m (f Integer) |
Appends a sample to a time series (https://redis.io/commands/ts.add).
O(M) when M is the number of compaction rules, or O(1) with no compaction
Since RedisTimeSeries 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Time series key. |
| -> TsAlterOpts | Alteration options. |
| -> m (f Status) |
Update the retention, chunk size, duplicate policy, and labels of an existing time series (https://redis.io/commands/ts.alter).
O(N) where N is the number of labels requested to update
Since RedisTimeSeries 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Time series key. |
| -> m (f Status) |
Arguments
| :: RedisCtx m f | |
| => ByteString | Time series key. |
| -> TsCreateOpts | Creation options. |
| -> m (f Status) |
Arguments
| :: RedisCtx m f | |
| => ByteString | Source time series key. |
| -> ByteString | Destination time series key. |
| -> TsAggregator | Aggregation function. |
| -> Integer | Bucket duration in milliseconds. |
| -> m (f Status) |
Arguments
| :: RedisCtx m f | |
| => ByteString | Source time series key. |
| -> ByteString | Destination time series key. |
| -> TsAggregator | Aggregation function. |
| -> Integer | Bucket duration in milliseconds. |
| -> Integer | Alignment timestamp in milliseconds. |
| -> m (f Status) |
Create a compaction rule with an aligned bucket timestamp (https://redis.io/commands/ts.createrule).
O(1)
Since RedisTimeSeries 1.8.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Time series key. |
| -> Double | Decrement amount. |
| -> m (f Integer) |
Decrease the value of the sample with the maximum timestamp, or create a new sample with a decremented value (https://redis.io/commands/ts.decrby).
O(M) when M is the number of compaction rules, or O(1) with no compaction
Since RedisTimeSeries 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Time series key. |
| -> Double | Decrement amount. |
| -> TsIncrByOpts | Update options. |
| -> m (f Integer) |
Decrease the value of the sample with the maximum timestamp, or create a new sample with a decremented value (https://redis.io/commands/ts.decrby).
O(M) when M is the number of compaction rules, or O(1) with no compaction
Since RedisTimeSeries 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Time series key. |
| -> Integer | Lower timestamp bound. |
| -> Integer | Upper timestamp bound. |
| -> m (f Integer) |
Delete all samples between two timestamps for a given time series (https://redis.io/commands/ts.del).
O(N) where N is the number of data points that will be removed
Since RedisTimeSeries 1.6.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Source time series key. |
| -> ByteString | Destination time series key. |
| -> m (f Status) |
Arguments
| :: RedisCtx m f | |
| => ByteString | Time series key. |
| -> m (f (Maybe TsSample)) |
Get the sample with the highest timestamp from a given time series (https://redis.io/commands/ts.get).
O(1)
Since RedisTimeSeries 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Time series key. |
| -> TsGetOpts | Read options. |
| -> m (f (Maybe TsSample)) |
Get the sample with the highest timestamp from a given time series (https://redis.io/commands/ts.get).
O(1)
Since RedisTimeSeries 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Time series key. |
| -> Double | Increment amount. |
| -> m (f Integer) |
Increase the value of the sample with the maximum timestamp, or create a new sample with an incremented value (https://redis.io/commands/ts.incrby).
O(M) when M is the number of compaction rules, or O(1) with no compaction
Since RedisTimeSeries 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Time series key. |
| -> Double | Increment amount. |
| -> TsIncrByOpts | Update options. |
| -> m (f Integer) |
Increase the value of the sample with the maximum timestamp, or create a new sample with an incremented value (https://redis.io/commands/ts.incrby).
O(M) when M is the number of compaction rules, or O(1) with no compaction
Since RedisTimeSeries 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Time series key. |
| -> m (f Reply) |
Returns information and statistics for a time series (https://redis.io/commands/ts.info).
The reply is a heterogeneous attribute map, so this wrapper returns the raw Reply.
O(1)
Since RedisTimeSeries 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Time series key. |
| -> TsInfoOpts | Information query options. |
| -> m (f Reply) |
Returns information and statistics for a time series (https://redis.io/commands/ts.info).
The reply is a heterogeneous attribute map, so this wrapper returns the raw Reply.
O(1)
Since RedisTimeSeries 1.0.0
Arguments
| :: RedisCtx m f | |
| => NonEmpty (ByteString, ByteString, Double) | Time series key, timestamp, and sample value triplets. |
| -> m (f [Integer]) |
Append new samples to one or more time series (https://redis.io/commands/ts.madd).
O(N cdot M) when N is the number of series updated and M is the number of compaction rules, or O(N) with no compaction
Since RedisTimeSeries 1.0.0
Arguments
| :: RedisCtx m f | |
| => NonEmpty ByteString | Filter expressions. |
| -> m (f Reply) |
Get the sample with the highest timestamp from each time series matching a specific filter (https://redis.io/commands/ts.mget).
The reply is heterogeneous and depends on label options, so this wrapper returns the raw Reply.
O(n) where n is the number of time-series that match the filters
Since RedisTimeSeries 1.0.0
Arguments
| :: RedisCtx m f | |
| => NonEmpty ByteString | Filter expressions. |
| -> TsMGetOpts | Read options. |
| -> m (f Reply) |
Get the sample with the highest timestamp from each time series matching a specific filter (https://redis.io/commands/ts.mget).
The reply is heterogeneous and depends on label options, so this wrapper returns the raw Reply.
O(n) where n is the number of time-series that match the filters
Since RedisTimeSeries 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Lower timestamp bound, or |
| -> ByteString | Upper timestamp bound, or |
| -> NonEmpty ByteString | Filter expressions. |
| -> m (f Reply) |
Query a range across multiple time series by filters in forward direction (https://redis.io/commands/ts.mrange).
The reply is heterogeneous and may include labels or grouped output, so this wrapper returns the raw Reply.
O(n/m+k) where n is the number of data points, m is the chunk size, and k is the number of returned samples
Since RedisTimeSeries 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Lower timestamp bound, or |
| -> ByteString | Upper timestamp bound, or |
| -> NonEmpty ByteString | Filter expressions. |
| -> TsMRangeOpts | Query options. |
| -> m (f Reply) |
Query a range across multiple time series by filters in forward direction (https://redis.io/commands/ts.mrange).
The reply is heterogeneous and may include labels or grouped output, so this wrapper returns the raw Reply.
O(n/m+k) where n is the number of data points, m is the chunk size, and k is the number of returned samples
Since RedisTimeSeries 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Lower timestamp bound, or |
| -> ByteString | Upper timestamp bound, or |
| -> NonEmpty ByteString | Filter expressions. |
| -> m (f Reply) |
Query a range across multiple time series by filters in reverse direction (https://redis.io/commands/ts.mrevrange).
The reply is heterogeneous and may include labels or grouped output, so this wrapper returns the raw Reply.
O(n/m+k) where n is the number of data points, m is the chunk size, and k is the number of returned samples
Since RedisTimeSeries 1.4.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Lower timestamp bound, or |
| -> ByteString | Upper timestamp bound, or |
| -> NonEmpty ByteString | Filter expressions. |
| -> TsMRangeOpts | Query options. |
| -> m (f Reply) |
Query a range across multiple time series by filters in reverse direction (https://redis.io/commands/ts.mrevrange).
The reply is heterogeneous and may include labels or grouped output, so this wrapper returns the raw Reply.
O(n/m+k) where n is the number of data points, m is the chunk size, and k is the number of returned samples
Since RedisTimeSeries 1.4.0
Arguments
| :: RedisCtx m f | |
| => NonEmpty ByteString | Filter expressions. |
| -> m (f [ByteString]) |
Get all time series keys matching a filter list (https://redis.io/commands/ts.queryindex).
O(n) where n is the number of time-series that match the filters
Since RedisTimeSeries 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Time series key. |
| -> ByteString | Lower timestamp bound, or |
| -> ByteString | Upper timestamp bound, or |
| -> m (f [TsSample]) |
Query a range in forward direction (https://redis.io/commands/ts.range).
O(n/m+k) where n is the number of data points, m is the chunk size, and k is the number of returned samples
Since RedisTimeSeries 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Time series key. |
| -> ByteString | Lower timestamp bound, or |
| -> ByteString | Upper timestamp bound, or |
| -> TsRangeOpts | Query options. |
| -> m (f [TsSample]) |
Query a range in forward direction (https://redis.io/commands/ts.range).
O(n/m+k) where n is the number of data points, m is the chunk size, and k is the number of returned samples
Since RedisTimeSeries 1.0.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Time series key. |
| -> ByteString | Lower timestamp bound, or |
| -> ByteString | Upper timestamp bound, or |
| -> m (f [TsSample]) |
Query a range in reverse direction (https://redis.io/commands/ts.revrange).
O(n/m+k) where n is the number of data points, m is the chunk size, and k is the number of returned samples
Since RedisTimeSeries 1.4.0
Arguments
| :: RedisCtx m f | |
| => ByteString | Time series key. |
| -> ByteString | Lower timestamp bound, or |
| -> ByteString | Upper timestamp bound, or |
| -> TsRangeOpts | Query options. |
| -> m (f [TsSample]) |
Query a range in reverse direction (https://redis.io/commands/ts.revrange).
O(n/m+k) where n is the number of data points, m is the chunk size, and k is the number of returned samples
Since RedisTimeSeries 1.4.0