| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Database.Redis.ManualCommands.Wait
Synopsis
- data WaitAofResult = WaitAofResult {}
- wait :: RedisCtx m f => Integer -> Integer -> m (f Integer)
- waitaof :: RedisCtx m f => Integer -> Integer -> Integer -> m (f WaitAofResult)
Documentation
data WaitAofResult Source #
Constructors
| WaitAofResult | |
Fields
| |
Instances
| Show WaitAofResult Source # | |
Defined in Database.Redis.ManualCommands.Wait Methods showsPrec :: Int -> WaitAofResult -> ShowS # show :: WaitAofResult -> String # showList :: [WaitAofResult] -> ShowS # | |
| Eq WaitAofResult Source # | |
Defined in Database.Redis.ManualCommands.Wait Methods (==) :: WaitAofResult -> WaitAofResult -> Bool # (/=) :: WaitAofResult -> WaitAofResult -> Bool # | |
| RedisResult WaitAofResult Source # | |
Defined in Database.Redis.ManualCommands.Wait | |
Arguments
| :: RedisCtx m f | |
| => Integer | Number of replicas to wait for. |
| -> Integer | Maximum time to wait in milliseconds. |
| -> m (f Integer) |
O(1) Wait for preceding writes to be acknowledged by a given number of replicas (https://redis.io/commands/wait).
Blocks until the asynchronous replication of all preceding write commands sent by the connection is completed.
Since Redis 3.0.0
Arguments
| :: RedisCtx m f | |
| => Integer | Number of local Redis instances to wait for AOF fsync on ( |
| -> Integer | Number of replicas to wait for AOF fsync on. |
| -> Integer | Maximum time to wait in milliseconds. |
| -> m (f WaitAofResult) |
O(1) Wait for preceding writes to be fsynced to the append-only file locally and/or on replicas (https://redis.io/commands/waitaof).
Blocks until all of the preceding write commands sent by the connection are written to the append-only file of the master and/or replicas.
Since Redis 7.2.0